<?php

namespace app\modules\application\controllers;

use app\modules\application\models\AadharDetails;
use yii\web\Controller;
use yii\filters\VerbFilter;
use yii;
use yii\filters\AccessControl;
use yii\helpers\ArrayHelper;


class AadharController extends Controller
{
    /**
     * @inheritDoc
     */
    public function behaviors()
    {
        return array_merge(
            parent::behaviors(),
            [
                'access' => [
                    'class' => AccessControl::class,
                    'rules' => [
                        [
                            'actions' => [
                                'logout', 'index', 'captcha'
                            ],
                            'allow' => true,
                            'roles' => ['@'],
                        ],
                    ],
                ],
                'verbs' => [
                    'class' => VerbFilter::className(),
                    'actions' => [
                        'delete' => ['POST'],
                    ],
                ],
            ]
        );
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => \yii\web\ErrorAction::class,
            ],
            'captcha' => [
                'class' => 'common\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    /**
     * Aadhar Details 
     * 
     */
    public function actionIndex()
    {
        // return $this->redirect(['../dashboard/index']);
        // die();

        if (!yii::$app->ApplicationOpen->Openwindow()) {
            return $this->redirect('../site/login');
        }
        
        if (Yii::$app->user->identity->ApplicationFinalSubmit == 1 || Yii::$app->user->identity->PaymentStatus == 1) {
            return $this->redirect(['../dashboard/index']);
        }

        /* check Form Status here And User is exsit*/
        if (isset(yii::$app->user->identity->ID) && !empty(yii::$app->user->identity->ID)) {
            $CandidateID = Yii::$app->user->identity->ID;
        } else {
            Yii::$app->session->setFlash('error', 'Unauthorised access.');
            return $this->redirect('../site/login');
        }

        $CandidateID = Yii::$app->user->identity->ID;
        $getFormStatusCheck = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'ID')
            ->bindValue(':input', 'WHERE CandidateID=' . $CandidateID . ' and ApplicationFormID=2')
            ->bindValue(':table', 'ApplicationFormStatusTbl')
            ->queryOne();
        if (empty($getFormStatusCheck)) {
            Yii::$app->session->setFlash('error', 'please fill your contact details');
            return $this->redirect(['../contact/index']);
        }
        $model = new AadharDetails();
        $GenderData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', 'ID,Gender')
            ->bindValue(':input', 'WHERE IsActive=1')
            ->bindValue(':table', 'GenderMst')
            ->bindValue(':orderBy', 'order By ID asc')
            ->queryAll();
        $Genders = (!empty($GenderData)) ? ArrayHelper::map($GenderData, 'ID', 'Gender') : [];

        $examDate = strtotime(date('Y-m-d', strtotime(yii::$app->params['examStartDate'])) . "-" . yii::$app->params['ageMin'] . " year");
        $MinYear = date('Y', ($examDate));
        $examDate = strtotime(date('Y-m-d', strtotime(yii::$app->params['examStartDate'])) . "-" . yii::$app->params['ageMax'] . " year");
        $MaxYear = date('Y', ($examDate));
        $isaadhar = '';
        //day name
        for ($i = 1; $i <= 31; $i++) {
            $DobDate[str_pad($i, 2, '0', STR_PAD_LEFT)] = str_pad($i, 2, '0', STR_PAD_LEFT);
        }
        //month name
        for ($m = 1; $m <= 12; ++$m) {
            $DobMonth[str_pad($m, 2, '0', STR_PAD_LEFT)] = date('F', mktime(0, 0, 0, $m, 1));
        }
        //year name
        for ($year = $MaxYear; $year <= $MinYear; $year++) {
            $DobYear[$year] = $year;
        }
        $cid = Yii::$app->user->identity->id;
        $applicationNo = Yii::$app->user->identity->ApplicationNumber;
        $aadharDetail = AadharDetails::find()->select('CandidateName,ApplicationNumber,GenderID,DOB,AadharNumber,NameOnAadhar,GenderOnAadharID,IsAadharNumber,AadharSelectedOption,DOBOnAadhar')
            ->where(['ID' => $cid])->one();
        $isaadhar = $aadharDetail->IsAadharNumber;
        if ($this->request->isPOST) {
            if ($model->load(Yii::$app->request->post()) && $model->validate()) {
                $aadhaarPostData = Yii::$app->request->post();
                foreach ($aadhaarPostData['AadharDetails'] as $key => $value) {
                    $aadhaarPostData['AadharDetails']["$key"] = Yii::$app->SanatizeInput->getInput($value);
                }

                $data =  $aadhaarPostData['AadharDetails'];
                $isaadhar    =  $data['IsAadharNumber'];
                $model->CandidateIP = $_SERVER['REMOTE_ADDR'];
                $AadharDataArray = [];

                $AadharDay = $data['AadharDay'];
                $AadharMonth = $data['AadharMonth'];
                $AadharYear = $data['AadharYear'];
                $AadharDataArray['CandidateID']  = $cid;
                $AadharDataArray['IsAadharNumber'] = $data['IsAadharNumber'];
                $AadharDataArray['AadharNumber'] = $data['AadharNumber'];
                $AadharDataArray['NameOnAadhar'] = $data['NameOnAadhar'];
                $AadharDataArray['GenderOnAadharID'] = $data['GenderOnAadharID'];
                $AadharDataArray['ApplicationFormID'] = 3;
                $AadharDataArray['createDate'] = date('Y-m-d H:i:s');
                if (empty($AadharDay) and empty($AadharMonth)  and empty($AadharYear)) {
                    $AadharDataArray['DOBOnAadhar'] = '';
                } else {
                    $AadharDataArray['DOBOnAadhar'] = $AadharDay . '-' . $AadharMonth . '-' . $AadharYear;
                }

                if(isset($AadharDataArray['IsAadharNumber']) && $AadharDataArray['IsAadharNumber'] == 0){
                    $AadharDataArray['AadharNumber'] = null;
                    $AadharDataArray['NameOnAadhar'] = null;
                    $AadharDataArray['GenderOnAadharID'] = null;
                    $AadharDataArray['AadharNumber'] = null;  
                    $AadharDataArray['DOBOnAadhar'] = ''; 
                }

                $selectVals = $aadhaarPostData['AadharDetails']['AadharSelectedOption'];
                if(isset($AadharDataArray['IsAadharNumber'],$selectVals) && $AadharDataArray['IsAadharNumber'] == 1 && $selectVals == 2){
                    $AadharDataArray['AadharNumber'] = null;
                    $AadharDataArray['NameOnAadhar'] = null;
                    $AadharDataArray['GenderOnAadharID'] = null;
                    $AadharDataArray['AadharNumber'] = null;
                    $AadharDataArray['DOBOnAadhar'] = '';   
                }

                if(isset($AadharDataArray['IsAadharNumber'],$selectVals) && $AadharDataArray['IsAadharNumber'] == 1 && $selectVals == 0){
                    $AadharDataArray['AadharNumber'] = null;
                    $AadharDataArray['NameOnAadhar'] = null;
                    $AadharDataArray['GenderOnAadharID'] = null;
                    $AadharDataArray['DOBOnAadhar'] = ''; 
                }

                $AadharDataArray['AadharSelectedOption'] = $data['AadharSelectedOption'];
                $json['user_data'] = $AadharDataArray;
                $jsonParam = json_encode($json);

                $sp = '{{UpdateCandidatedata}}';
                $response = Yii::$app->db->createCommand("exec $sp @json = :json")
                    ->bindValue(':json', $jsonParam)
                    ->execute();
                if (isset($response) && $response == 0) {
                    $moduleName = 'Aadhar-Details';
                    $activityName = 'Next-Button';
                    $data = array("moduleName" => $moduleName, "activityName" => $activityName);
                    Yii::$app->useract->useract($data);
                    Yii::$app->session->setFlash('success', 'Data saved successfully.');
                    return $this->redirect(['../exam-center/index']);
                } else {
                    Yii::$app->session->setFlash('error', 'Something went wrong.');
                    return $this->redirect(['../aadhar/index']);
                }
            } else {
                $model->loadDefaultValues();
            }
        }
        return $this->render('aadharDetailsForm', [
            'model' => $model,
            'genders' => $Genders,
            'aadharDetail' => $aadharDetail,
            'IsAadharNumber' => $isaadhar,
            'backLink' => 'contact/index',
            'DobDate'   => $DobDate,
            'DobMonth'   => $DobMonth,
            'DobYear'   =>  $DobYear
        ]);
    }
}
