<?php

namespace app\modules\application\controllers;

use app\modules\application\models\CandidateAdditionalDetailsTbl;
use app\modules\application\models\ApplicationFormStatusTbl;
use yii\web\Controller;
use yii\filters\VerbFilter;
use yii;
use yii\filters\AccessControl;
//use app\modules\application\models\CandidateQualificationDetailsTbl;
use yii\helpers\Json;


class AdditionalController extends Controller
{
    /**
     * @inheritDoc
     */
    public function behaviors()
    {
        return array_merge(
            parent::behaviors(),
            [
                'access' => [
                    'class' => AccessControl::class,
                    'rules' => [
                        [
                            'actions' => [
                                'logout', 'index', 'aadhardetailsform', 'contactdetailsform',
                                'personaldetailsform', 'postgraduation', 'additional',
                                'document-upload', 'review-application-form', 'citylist',
                                'reviewapplicationform', 'reviewpdf', 'findModel',
                                'findPersonDetailSaveModel', 'findPersonalModel',
                                'passyear', 'resultmode', 'resultmodedistict', 'application-status',
                                'documentUpload', 'fileuploaded', 'examcenterdetailsform', 'examcenterdetailsformlink',
                                'getExamCenterQPData', 'reviewpdf', 'resultmode-distict', 'captcha', 'sendreviewpdf', 'payment-receipt'
                            ],
                            'allow' => true,
                            'roles' => ['@'],
                        ],
                    ],
                ],
                'verbs' => [
                    'class' => VerbFilter::className(),
                    'actions' => [
                        'delete' => ['POST'],
                    ],
                ],
            ]
        );
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => \yii\web\ErrorAction::class,
            ],
            'captcha' => [
                'class' => 'common\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    /**
     * Additional Details 
     * 
     */
    public function actionIndex()
    {
        // return $this->redirect(['../dashboard/index']);
        // die();
       
        if (!yii::$app->ApplicationOpen->Openwindow()) {
            return $this->redirect(['/site/login']);
        }
        //check if form submitted 
        if (Yii::$app->user->identity->ApplicationFinalSubmit == 1 || Yii::$app->user->identity->PaymentStatus == 1) {
            return $this->redirect(['../dashboard/index']);
        }
        //Check MAX AGE CRITERIA for NIFT:
        if(!Yii::$app->masterdata->checkAgeCriteria()){
            Yii::$app->session->setFlash('error', 'You are not full filling the max age criteria of NIFT.');
            return $this->redirect(['../personal/index']);
        }
        $CandidateId = Yii::$app->user->identity->ID;
        $getFormStatusCheck = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'ID')
            ->bindValue(':input', 'WHERE CandidateID=' . $CandidateId . ' and ApplicationFormID=5')
            ->bindValue(':table', 'ApplicationFormStatusTbl')
            ->queryOne();
        if (empty($getFormStatusCheck)) {
            Yii::$app->session->setFlash('error', 'please fill your Qualification details');
            return $this->redirect(['../qualification/index']);
        }

        $model = CandidateAdditionalDetailsTbl::findOne(['CandidateID' => Yii::$app->user->identity->ID]);
        if (isset($model) && !empty($model)) {
            $model = $model;
        } else {
            $model = new CandidateAdditionalDetailsTbl();
        }

        if ($this->request->isPost) {
            if ($model->load(Yii::$app->request->post()) && $model->validate()) {
                $postData = Yii::$app->request->post();
                foreach ($postData['CandidateAdditionalDetailsTbl'] as $key => $value) {
                    $postData['CandidateAdditionalDetailsTbl']["$key"] = Yii::$app->SanatizeInput->getInput($value);
                }
                $contentArray = array();
                $contentArray['CandidateID'] = Yii::$app->user->identity->ID;
                $contentArray['ApplicationNumber'] = Yii::$app->user->identity->ApplicationNumber;
                $contentArray['IsActive'] = 1;
                $contentArray['ApplicationFormID'] = 6;
                $contentArray['CreatedDate'] = date('Y-m-d H:i:s');

                $contentArray['IsArtesianOrSonOrDaughterOfArtisian'] = $postData['CandidateAdditionalDetailsTbl']['IsArtesianOrSonOrDaughterOfArtisian'];
                $contentArray['ArtesianCardDetail'] = $postData['CandidateAdditionalDetailsTbl']['ArtesianCardDetail'];
                $contentArray['ArtesianCardIDNumber'] = $postData['CandidateAdditionalDetailsTbl']['ArtesianCardIDNumber'];
                $contentArray['ParentsArtesianCardIDNumber'] = $postData['CandidateAdditionalDetailsTbl']['ParentsArtesianCardIDNumber'];

                if ($postData['CandidateAdditionalDetailsTbl']['IsArtesianOrSonOrDaughterOfArtisian'] == 1) {
            
                    if($contentArray['ArtesianCardDetail'] == 1 ){
                        //Artesian card ID Number:
                        $contentArray['ArtesianCardIDNumber'] = $postData['CandidateAdditionalDetailsTbl']['ArtesianCardIDNumber'];
                        $contentArray['ParentsArtesianCardIDNumber'] = null;

                    }else if ($contentArray['ArtesianCardDetail'] == 2 ) {
                        //Parents Artesian Card ID Number:
                        $contentArray['ParentsArtesianCardIDNumber'] = $postData['CandidateAdditionalDetailsTbl']['ParentsArtesianCardIDNumber'];
                        $contentArray['ArtesianCardIDNumber'] = null;

                    } else {
                        $contentArray['ArtesianCardIDNumber'] = null;
                        $contentArray['ParentsArtesianCardIDNumber'] = null;
                    }

                } else {
                    $contentArray['ArtesianCardDetail'] = null;
                    $contentArray['ArtesianCardIDNumber'] = null;
                    $contentArray['ParentsArtesianCardIDNumber'] = null;
                }


                $json = Json::encode($contentArray);
                $sp = '{{%spCondidateAdditionalUpdate}}';
                $response = Yii::$app->db->createCommand("exec $sp @json = :json")
                    ->bindValue(':json', $json)
                    ->execute();
                if (isset($response) && $response == 0) {
                    $moduleName = 'Additional-Details';
                    $activityName = 'Next-Button';
                    $data = array("moduleName" => $moduleName, "activityName" => $activityName);
                    Yii::$app->useract->useract($data);
                    Yii::$app->session->setFlash('success', 'Data saved successfully.');
                    return $this->redirect(['../document-upload/index']);
                } else {
                    Yii::$app->session->setFlash('error', 'Something went wrong.');
                    return $this->redirect(['../additional/index']);
                }
            }
        }
        //print_r($model); die;
        return $this->render('additional', [
            'model' => $model,
            'backLink' => 'qualification/index',
        ]);
    }
}
