<?php

namespace app\modules\application\controllers;

use app\modules\application\models\CandidateTbl;
use app\modules\application\models\ApplicationFormStatusTbl;
use yii\web\Controller;
use yii\filters\VerbFilter;
use yii;
use yii\filters\AccessControl;
use frontend\modules\application\models\DocumentMst;
use yii\web\UploadedFile;
use frontend\modules\application\models\CandidateDocumentTbl;
use yii\validators\FileValidator;

class DocumentUploadController extends Controller
{
    /**
     * @inheritDoc
     */
    public function behaviors()
    {
        return array_merge(
            parent::behaviors(),
            [
                'access' => [
                    'class' => AccessControl::class,
                    'rules' => [
                        [
                            'actions' => [
                                'logout',
                                'index',
                                'captcha',
                                'submit-document',
                                'image',
                                'download-file'
                            ],
                            'allow' => true,
                            'roles' => ['@'],
                        ],
                    ],
                ],
                'verbs' => [
                    'class' => VerbFilter::className(),
                    'actions' => [
                        'delete' => ['POST'],
                    ],
                ],
            ]
        );
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => \yii\web\ErrorAction::class,
            ],
            'captcha' => [
                'class' => 'common\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    public function actionIndex()
    {

        $ApplicationWindowStartStatus = Yii::$app->ApplicationOpen->Openwindow();
        $CorrectionWindowStartStatus = Yii::$app->CorrectionWindow->Openwindow();

        $isCandidateAllowCorrection = Yii::$app->CheckCorrectionAndApplicationStatus->CheckStatus($ApplicationWindowStartStatus, $CorrectionWindowStartStatus);
        if (isset($isCandidateAllowCorrection, $isCandidateAllowCorrection['status'], $isCandidateAllowCorrection['msg']) && !empty($isCandidateAllowCorrection) && ($isCandidateAllowCorrection['status'] == 0) && !empty($isCandidateAllowCorrection['msg'])) {
            Yii::$app->session->setFlash('error', $isCandidateAllowCorrection['msg']);
            return $this->redirect(['../dashboard/index']);
        }


        $CandidateId = Yii::$app->user->identity->ID;
        $ApplicationNumber = Yii::$app->user->identity->ApplicationNumber;
        $FolderName = Yii::$app->params['ExamName'];



        if (!Yii::$app->masterdata->checkAgeCriteria()) {
            Yii::$app->session->setFlash('error', 'You are not full filling the max age criteria of NIFT.');
            return $this->redirect(['../personal/index']);
        }

        if (isset(yii::$app->user->identity->ID) && !empty(yii::$app->user->identity->ID)) {
            //if (isset(yii::$app->user->identity->PaymentStatus) && yii::$app->user->identity->PaymentStatus != 1) {
            $CandidateID = Yii::$app->user->identity->ID;
            $formAttrbute = $this->getAllDocumentValidationVarable();
            $fieldValidationRule = $this->getAllDocumentValidation();

            $candidateMasterData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                ->bindValue(':select', 'PhysicalDisability,NeedScribe,CastCategoryID')
                ->bindValue(':input', 'WHERE ID=' . $CandidateID)
                ->bindValue(':table', 'CandidateTbl')->queryOne();

            $resultawaited = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                ->bindValue(':select', 'PassStatus,PostGraduatePassStatus')
                ->bindValue(':input', 'WHERE CandidateID=' . $CandidateID)
                ->bindValue(':table', 'CandidateQualificationDetailsTbl')->queryOne();

            $artesianDocument = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                ->bindValue(':select', 'SubjecSpecializationMstID')
                ->bindValue(':input', 'WHERE IsArtisanSonDoughter=1 and CandidateID=' . $CandidateID)
                ->bindValue(':table', 'CandidateApplySubjectTbl')->queryOne();


            $twelveDocument = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                ->bindValue(':select', 'PassStatus12')
                ->bindValue(':input', 'WHERE IsActive=1 and CandidateID=' . $CandidateID)
                ->bindValue(':table', 'CandidateQualificationDetailsTblFinal')->queryOne();

            //echo $twelveDocument['PassStatus12'];die;

            //  correction window 

            if (isset($ApplicationWindowStartStatus, $CorrectionWindowStartStatus) && ($ApplicationWindowStartStatus == 0) && ($CorrectionWindowStartStatus == 1)) {
                
                $personalDetailsDataCorrection = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                    ->bindValue(':select', 'PersonalDetails')
                    ->bindValue(':input', "WHERE CandidateID=$CandidateID AND ApplicationNumber='$ApplicationNumber' and IsActive=1 ")
                    ->bindValue(':table', 'CandidateCorrectionDataTbl')
                    ->queryOne();
                if (isset($personalDetailsDataCorrection['PersonalDetails']) && !empty($personalDetailsDataCorrection['PersonalDetails']) && $this->json_validator($personalDetailsDataCorrection['PersonalDetails'])) {
                    $personaldataOverrides = json_decode($personalDetailsDataCorrection['PersonalDetails'], true);
                    foreach ($candidateMasterData as $key1 => $value1) {
                        if (array_key_exists("$key1", $personaldataOverrides)) {
                            $candidateMasterData[$key1] = $personaldataOverrides["$key1"];
                        }
                    }
                }
            }

            //  correction window 


            $finalArray = array();
            foreach ($fieldValidationRule as $data) {
                $documentName = strtolower(trim($data['DocumentName']));

                if (isset($data['IsRequired']) && $data['IsRequired'] == 1) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($candidateMasterData['CastCategoryID']) && !empty($candidateMasterData['CastCategoryID']) && $data['IsRequired'] == 0 && ($candidateMasterData['CastCategoryID'] != 1) &&  preg_match("/category/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($candidateMasterData['PhysicalDisability']) && !empty($candidateMasterData['CastCategoryID']) && $data['IsRequired'] == 0 && (in_array($candidateMasterData['PhysicalDisability'], [1, 2]))  &&  preg_match("/pwd/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($artesianDocument['SubjecSpecializationMstID']) && $data['IsRequired'] == 0 && ($artesianDocument['SubjecSpecializationMstID'] == 10074) &&  preg_match("/Artisan/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($twelveDocument['PassStatus12']) && $data['IsRequired'] == 0 && ($twelveDocument['PassStatus12'] == 1) &&  preg_match("/twelve certificate/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($twelveDocument['PassStatus12']) && $data['IsRequired'] == 0 && ($twelveDocument['PassStatus12'] == 2) &&  preg_match("/supporting document of twelve/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                }
            }


            // echo '<pre>';print_r($finalArray); die;

            $modelDynamic = new \yii\base\DynamicModel($formAttrbute);
            foreach ($fieldValidationRule as $DocAllArray) {
                $modelDynamic->addRule([$DocAllArray['DocumentCode']], 'required', ['message' => $DocAllArray['DocumentName'] . " is required"])
                    ->addRule([$DocAllArray['DocumentCode']], 'file', ['extensions' => $DocAllArray['DocumentType']])
                    ->addRule([$DocAllArray['DocumentCode']], 'file', ['minSize' => $DocAllArray['DocumentMinSize'], 'maxSize' => $DocAllArray['DocumentMaxSize']]);
            }
            if (Yii::$app->request->isPost) {
                if ($modelDynamic->load(Yii::$app->request->post())) {
                    foreach ($fieldValidationRule as $documentCode) {
                        if (UploadedFile::getInstance($modelDynamic, trim($documentCode['DocumentCode']))) {
                            $selectFile = trim($documentCode['DocumentCode']);
                            $documentType = trim($documentCode['DocumentName']);
                            $documentMinSize = trim($documentCode['DocumentMinSize']);
                            $documentMaxSize = trim($documentCode['DocumentMaxSize']);
                            $documentExtension = trim($documentCode['DocumentType']);
                        }
                    }
                    $docid = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                        ->bindValue(':select', 'ID')
                        ->bindValue(':input', "WHERE DocumentCode='" . $selectFile . "'")
                        ->bindValue(':table', 'DocumentMst')->queryOne();
                    $doc_id = $docid['ID'];
                    $applicationNumber = Yii::$app->user->identity->ApplicationNumber;
                    $apiPath = yii::$app->params['APIPathAPI'];
                    $modelDynamic->{$selectFile} = UploadedFile::getInstance($modelDynamic, $selectFile);
                    $validator = new FileValidator([
                        'extensions' =>
                        $documentExtension,
                        'mimeTypes' => ['image/jpg', 'image/jpeg', 'application/pdf'],
                        'maxSize' => $documentMaxSize,
                        'minSize' => $documentMinSize,
                    ]);
                    if (!$validator->validate($modelDynamic->{$selectFile}, $error)) {
                        Yii::$app->session->setFlash('error', 'Please upload valid ' . ucwords($documentType));
                        return $this->redirect(['../document-upload/index']);
                    }
                    if (isset($modelDynamic->{$selectFile}->name) && !empty($modelDynamic->{$selectFile}->name) && (substr_count($modelDynamic->{$selectFile}->name, '.') > 1)) {
                        Yii::$app->session->setFlash('error', ucwords($documentType) . ' has an invalid double extension. Kindly rename and upload again.');
                        return $this->redirect(['../document-upload/index']);
                    }
                    $mime_type = mime_content_type($modelDynamic->{$selectFile}->tempName);
                    $array = array('application/pdf', 'image/jpeg');
                    if (isset($mime_type) && !empty($mime_type)) {
                        if (!in_array($mime_type, $array)) {
                            Yii::$app->session->setFlash('error', 'Please upload valid ' . ucwords($documentType));
                            return $this->redirect(['../document-upload/index']);
                        }
                    }

                    $content_memtype = $modelDynamic->{$selectFile}->type;
                    if (isset($content_memtype) && !empty($content_memtype) && (!in_array($content_memtype, $array))) {
                        Yii::$app->session->setFlash('error', 'Please upload valid ' . ucwords($documentType));
                        return $this->redirect(['../document-upload/index']);
                    }

                    if (isset($modelDynamic->{$selectFile}->tempName) && !empty($modelDynamic->{$selectFile}->tempName) && preg_match("/photo/i", strtolower($documentType))) {
                        $mime_type = mime_content_type($modelDynamic->{$selectFile}->tempName);
                        $array = array('image/jpeg');
                        if (isset($mime_type) && !empty($mime_type)) {
                            if (!in_array($mime_type, $array)) {
                                Yii::$app->session->setFlash('error', 'Please upload valid ' . ucwords($documentType));
                                return $this->redirect(['../document-upload/index']);
                            }
                        }

                        $photoStatus = $this->CheckValidImage($modelDynamic->{$selectFile}->tempName);
                        if (isset($photoStatus, $photoStatus['status']) && ($photoStatus['status'] == 'error')) {
                            Yii::$app->session->setFlash('error', $photoStatus['message']);
                            return $this->redirect(['../document-upload/index']);
                        }

                        // $photoStatus = $this->faceDetection($modelDynamic->{$selectFile}->tempName);
                        // if (!$photoStatus) {
                        //     Yii::$app->session->setFlash('error', 'Please upload valid ' . ucwords($documentType));
                        //     return $this->redirect(['../document-upload/index']);
                        // }
                    } else if (isset($modelDynamic->{$selectFile}->tempName) && !empty($modelDynamic->{$selectFile}->tempName) &&  preg_match("/signature/i", strtolower($documentType))) {
                        $mime_type = mime_content_type($modelDynamic->{$selectFile}->tempName);
                        $array = array('image/jpeg');
                        if (isset($mime_type) && !empty($mime_type)) {
                            if (!in_array($mime_type, $array)) {
                                Yii::$app->session->setFlash('error', 'Please upload valid ' . ucwords($documentType));
                                return $this->redirect(['../document-upload/index']);
                            }
                        }

                        $signatureStatus = $this->faceDetection($modelDynamic->{$selectFile}->tempName);
                        if ($signatureStatus) {
                            Yii::$app->session->setFlash('error', 'Please upload valid ' . ucwords($documentType));
                            return $this->redirect(['../document-upload/index']);
                        }
                    }
                    $path = Yii::$app->user->identity->ApplicationNumber;
                    $Fname = $selectFile . '_' . time(); //trim($dynamicName) . $selectFile . '_' . time();
                    if (isset(yii::$app->params['IsdocumentuploadAPI']) && !empty(yii::$app->params['IsdocumentuploadAPI'])) {

                        //$responsejson = $this->uploadDocument($applicationNumber, $selectFile, $modelDynamic->{$selectFile}->tempName, $modelDynamic->{$selectFile}->type, $modelDynamic->{$selectFile}->name, $apiPath);

                        $responsejson = Yii::$app->AzureFileUploadComponent->uploadDocument($applicationNumber, $modelDynamic->{$selectFile}, $selectFile, $modelDynamic->{$selectFile}->type, $FolderName);

                        $response = json_decode($responsejson, true);
                        // echo '<pre>';print_r($response); die;
                        if (isset($response['Status']) && !empty($response['Status'])) {
                            $actuallyFileName = $response['filename'];
                        } else if (isset($response['Status']) && empty($response['Status'])) {
                            Yii::$app->session->setFlash('error', 'Something went wrong.');
                            return $this->redirect(['../document-upload/index']);
                        } else {
                            Yii::$app->session->setFlash('error', 'Something went wrong.');
                            return $this->redirect(['../document-upload/index']);
                        }
                    } else {
                        $actuallyFileName = Yii::$app->filesupload->uploadprocess($Fname, $path, $modelDynamic, $selectFile);
                    }
                    if (isset($actuallyFileName) && !empty($actuallyFileName)) {
                            $jsonArray = array();
                            $jsonArray['CandidateID'] = Yii::$app->user->identity->ID;
                            $jsonArray['ModifyBy'] = Yii::$app->user->identity->CandidateName;
                            $jsonArray['DocumentID'] = $doc_id;
                            $jsonArray['UploadDocument'] = $actuallyFileName;
                            $jsonArray['CreateDate'] = date('Y-m-d h:i:s');
                            $jsonArray['IsActive'] = 1;
                            $jsonArray['ClientIP'] = Yii::$app->request->getUserIP();
                            $jsonParams = json_encode($jsonArray);
                        if (isset($ApplicationWindowStartStatus, $CorrectionWindowStartStatus) && ($ApplicationWindowStartStatus == 1) && ($CorrectionWindowStartStatus == 0)) {
                                                       
                            $response = yii::$app->db->createCommand("exec spCandidateDocument :json")->bindValue('json', $jsonParams)->execute();
                            if (isset($response) && !empty($response)) {

                                //Activity Log START
                                $moduleName = 'Document Upload';
                                $nextURL = 'final-reviews/index';
                                $NextActivityURL = isset($nextURL) ? str_replace("../", "", $nextURL) : 'NA';
                                $activityName = $moduleName . ' ' . Yii::$app->params['ActivityDescriptionForControllers'] . ' ' . $NextActivityURL;
                                $data = array(
                                    "applicationWindowStart" => $ApplicationWindowStartStatus,
                                    "correctionWindowStart" => $CorrectionWindowStartStatus,
                                    "moduleName" => $moduleName,
                                    "activityName" => $activityName
                                );
                                Yii::$app->useract->useract($data);
                                //Activity Log END

                                // Yii::$app->session->setFlash('success', 'Uploaded successfully');
                                Yii::$app->session->setFlash('success', ucwords($documentType) . " Uploaded Successfully");
                                // return $this->redirect(['../final-reviews/index']);


                            } else {
                                Yii::$app->session->setFlash('error', 'Something went wrong.');
                                return $this->redirect(['../document-upload/index']);
                            }
                        } else if (isset($ApplicationWindowStartStatus, $CorrectionWindowStartStatus) && ($ApplicationWindowStartStatus == 0) && ($CorrectionWindowStartStatus == 1)) {
                           
                            
                            $UploadDocumentDetailsOverrides = array();
                            $UploadDocumentDetailsData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                                ->bindValue(':select', 'UploadDocumentDetails')
                                ->bindValue(':input', "WHERE CandidateID=$CandidateID AND ApplicationNumber='$ApplicationNumber' and IsActive=1 ")
                                ->bindValue(':table', 'CandidateCorrectionDataTbl')
                                ->queryOne();

                            if (isset($UploadDocumentDetailsData['UploadDocumentDetails']) && !empty($UploadDocumentDetailsData['UploadDocumentDetails']) && $this->json_validator($UploadDocumentDetailsData['UploadDocumentDetails'])) {
                                $UploadDocumentDetailsOverrides = json_decode($UploadDocumentDetailsData['UploadDocumentDetails'], true);
                                foreach ($UploadDocumentDetailsOverrides as $key1 => $docdatas) {
                                    if (isset($doc_id, $docdatas, $docdatas['DocumentID']) && !empty($doc_id) && !empty($docdatas) && !empty($docdatas['DocumentID']) && $docdatas['DocumentID'] == $doc_id) {
                                        $UploadDocumentDetailsOverrides[$key1]['UploadDocument'] = $actuallyFileName;
                                    }
                                }
                                $docIDArray = array_column($UploadDocumentDetailsOverrides, 'DocumentID');
                                if (isset($docIDArray, $doc_id) && !empty($docIDArray) && !empty($doc_id) && is_array($docIDArray) && !in_array($doc_id, $docIDArray)) {
                                    array_push($UploadDocumentDetailsOverrides, $jsonArray);
                                }
                            } else {
                                array_push($UploadDocumentDetailsOverrides, $jsonArray);
                            }
                            $sp3 = '{{%saveUpdateCorrectionWindowData}}';
                            $finalJson = json_encode($UploadDocumentDetailsOverrides);

                            $responseCorrection = Yii::$app->db->createCommand("exec $sp3 :candidateID,:ApplicationNumber,:jsonData,:fieldname,:tablename,:currentTime,:candidateIP")
                                ->bindValue(':candidateID', $CandidateID)
                                ->bindValue(':ApplicationNumber', $ApplicationNumber)
                                ->bindValue(':jsonData', $finalJson)
                                ->bindValue(':fieldname', 'UploadDocumentDetails')
                                ->bindValue(':tablename', 'CandidateCorrectionDataTbl')
                                ->bindValue(':currentTime', date('Y-m-d H:i:s'))
                                ->bindValue(':candidateIP', Yii::$app->masterdata->getCandidateIP())
                                ->execute();
                            if (isset($responseCorrection) && ($responseCorrection == 0)) {
                                //Activity Log START
                                $applicationWindowStartActivityLog = Yii::$app->params['applicationWindowStartActivityLog'];
                                $correctionWindowStartActivityLog = Yii::$app->params['correctionWindowStartActivityLog'];
                                $moduleName = 'Document Upload';
                                $activityName = ucwords($documentType) . ' upload';
                                $data = array(
                                    "moduleName" => $moduleName,
                                    "activityName" => $activityName,
                                    "applicationWindowStart" => $applicationWindowStartActivityLog,
                                    "correctionWindowStart" => $correctionWindowStartActivityLog,
                                    "RegistrationModeType" => NULL,
                                    "RegistrationModeValue" => NULL
                                );
                                Yii::$app->useract->useract($data);
                                // end
                                Yii::$app->session->setFlash('success', ucwords($documentType) . " Uploaded Successfully");
                                return $this->redirect(['../document-upload/index']);
                            } else {
                                Yii::$app->session->setFlash('error', 'Something went wrong.');
                                return $this->redirect(['../document-upload/index']);
                            }
                        }
                    } else {
                        Yii::$app->session->setFlash('error', 'Something went wrong.');
                        return $this->redirect(['../document-upload/index']);
                    }
                }
            }
            $docData = yii::$app->db->createCommand("exec SpCandidateUplodedDoc '$CandidateID'")->queryAll();
            $visiviltyCount = 0;
            if (isset($finalArray) && isset($docData) &&  !empty($finalArray) && !empty($docData)) {
                foreach ($finalArray as $k1 => $v1) {
                    foreach ($docData as $k2 => $v2) {
                        if (isset($v1) && isset($v2['DocumentID']) && !empty($v1['ID']) && !empty($v2['DocumentID']) && $v1['ID'] == $v2['DocumentID']) {
                            //$finalArray[$k1]['UploadDocument'] = $v2['UploadDocument'];

                            $IsFilePresent = Yii::$app->AzureFileUploadComponent->isDocumentPresent($v2['UploadDocument']);
                            if (isset($v2['UploadDocument']) && !empty($v2['UploadDocument']) && !empty($IsFilePresent)) {
                                $documemntPath = yii::$app->params['documentPathAPI'] . '/' . yii::$app->params['containerName'];
                                $finalArray[$k1]['UploadDocument'] = $documemntPath . '/' . $v2['UploadDocument'];
                            } else {
                                $finalArray[$k1]['UploadDocument'] = null;
                            }

                        }
                    }
                }
            }

            //Correction Data OverRide:
            if (isset($ApplicationWindowStartStatus, $CorrectionWindowStartStatus) && ($ApplicationWindowStartStatus == 0) && ($CorrectionWindowStartStatus == 1)) {
                $correctionDocDetailsData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                    ->bindValue(':select', 'UploadDocumentDetails')
                    ->bindValue(':input', "WHERE CandidateID=$CandidateID AND ApplicationNumber='$ApplicationNumber' and IsActive=1 ")
                    ->bindValue(':table', 'CandidateCorrectionDataTbl')
                    ->queryOne();
                if (isset($correctionDocDetailsData['UploadDocumentDetails']) && !empty($correctionDocDetailsData['UploadDocumentDetails']) && $this->json_validator($correctionDocDetailsData['UploadDocumentDetails'])) {
                    $docDataArray = json_decode($correctionDocDetailsData['UploadDocumentDetails'], true);
                    if (isset($finalArray) && isset($docDataArray) && !empty($finalArray) && !empty($docDataArray)) {
                        foreach ($finalArray as $k1 => $v1) {
                            foreach ($docDataArray as $k2 => $v2) {
                                if (isset($v1) && isset($v2['DocumentID']) && !empty($v1['ID']) && !empty($v2['DocumentID']) && $v1['ID'] == $v2['DocumentID']) {
                                    $finalArray[$k1]['UploadDocument'] = $v2['UploadDocument'];
                                }
                            }
                        }
                    }
                }
            }

            foreach ($finalArray as $k1 => $v1) {
                if (isset($v1, $v1['UploadDocument']) && !empty($v1) && !empty($v1['UploadDocument'])) {
                    $visiviltyCount++;
                }
            }


            $nextbuttonvisible = 0;
            if (isset($visiviltyCount) && isset($finalArray) && !empty($visiviltyCount) && !empty($finalArray) && ($visiviltyCount == count($finalArray))) {
                $nextbuttonvisible = 1;
            }
            //echo "<pre>"; print_r($finalArray); die;
            return $this->render('document-upload', [
                'model' => $modelDynamic,
                'finalArray' => $finalArray,
                'backLink' => 'qualification/index',
                'nextbuttonvisible' => $nextbuttonvisible,
                'correctionStatus' => $CorrectionWindowStartStatus,
            ]);
            // } else {
            //     Yii::$app->session->setFlash('error', 'You already pay kindly download your application pdf.');
            //     return $this->redirect('../dashboard/index');
            // }
        } else {
            Yii::$app->session->setFlash('error', 'Unauthorised access.');
            return $this->redirect('../site/login');
        }
    }

    public function getAllDocumentValidationVarable()
    {
        //        $DB = Yii::$app->session->get('NewDB');
        //        if (empty($DB)) {
        //            return $this->redirect(['/site/login']);
        //        }
        $documentCode = '';
        $allDocumentArray = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', '*')
            ->bindValue(':input', "WHERE IsActive=1")
            ->bindValue(':table', 'DocumentMst')->queryAll();
        if (isset($allDocumentArray) && !empty($allDocumentArray)) {
            $documentCode = array_column($allDocumentArray, 'DocumentCode');
        }
        return $documentCode;
    }

    public function getAllDocumentValidation()
    {
        //        $DB = Yii::$app->session->get('NewDB');
        //        if (empty($DB)) {
        //            return $this->redirect(['/site/login']);
        //        }
        $validationArray = array();
        $allDocumentArray = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', '*')
            ->bindValue(':input', "WHERE IsActive=1 order by ID asc")
            ->bindValue(':table', 'DocumentMst')->queryAll();
        if (isset($allDocumentArray) && !empty($allDocumentArray)) {
            return $allDocumentArray;
        }
        return $validationArray;
    }

    public function faceDetection($path)
    {
        Yii::$app->facedetect->scan("$path"); //image to be uploaded :use temp path
        $faces =  Yii::$app->facedetect->getFaces();
        $imageInfo = getimagesize($path);
        if (!empty($faces)) {
            $actualWidth = $imageInfo[0];
            $actualHeight = $imageInfo[1];
            $faceWidth = $faces[0]['width'];
            $faceHeight = $faces[0]['height'];
            if ((($faceWidth / $actualWidth) * 100 >= 25)) {
                return true;
            } else {
                return false;
            }
        } else {
            return false;
        }
    }

    /**
   
     **/
    public function actionSubmitDocument()
    {

        if (isset(yii::$app->user->identity->ID) && !empty(yii::$app->user->identity->ID)) {
            // if (isset(yii::$app->user->identity->PaymentStatus) && yii::$app->user->identity->PaymentStatus != 1) {
            $ApplicationWindowStartStatus = Yii::$app->ApplicationOpen->Openwindow();
            $CorrectionWindowStartStatus = Yii::$app->CorrectionWindow->Openwindow();

            $isCandidateAllowCorrection = Yii::$app->CheckCorrectionAndApplicationStatus->CheckStatus($ApplicationWindowStartStatus, $CorrectionWindowStartStatus);
            if (isset($isCandidateAllowCorrection, $isCandidateAllowCorrection['status'], $isCandidateAllowCorrection['msg']) && !empty($isCandidateAllowCorrection) && ($isCandidateAllowCorrection['status'] == 0) && !empty($isCandidateAllowCorrection['msg'])) {
                Yii::$app->session->setFlash('error', $isCandidateAllowCorrection['msg']);
                return $this->redirect(['../dashboard/index']);
            }



            $CandidateID = Yii::$app->user->identity->ID;
            $ApplicationNumber = Yii::$app->user->identity->ApplicationNumber;
            $fieldValidationRule = $this->getAllDocumentValidation();
            $checkpoint = ApplicationFormStatusTbl::findOne(['CandidateID' => Yii::$app->user->identity->ID, 'ApplicationFormID' => 7]);
            if (!$checkpoint) {
                $candidate_id = Yii::$app->user->identity->ID;
                $form_id = 7;
                yii::$app->db->createCommand("exec FormSubmitConfirmation '$candidate_id','$form_id' ")->execute();  //finial submission   
            }
            $candidateMasterData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                ->bindValue(':select', 'PhysicalDisability,NeedScribe,CastCategoryID')
                ->bindValue(':input', 'WHERE ID=' . $CandidateID)
                ->bindValue(':table', 'CandidateTbl')->queryOne();

            // Correction Window 
            if (isset($ApplicationWindowStartStatus, $CorrectionWindowStartStatus) && ($ApplicationWindowStartStatus == 0) && ($CorrectionWindowStartStatus == 1)) {
                $personalDetailsDataCorrection = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                    ->bindValue(':select', 'PersonalDetails')
                    ->bindValue(':input', "WHERE CandidateID=$CandidateID AND ApplicationNumber='$ApplicationNumber' and IsActive=1 ")
                    ->bindValue(':table', 'CandidateCorrectionDataTbl')
                    ->queryOne();
                if (isset($personalDetailsDataCorrection['PersonalDetails']) && !empty($personalDetailsDataCorrection['PersonalDetails']) && $this->json_validator($personalDetailsDataCorrection['PersonalDetails'])) {
                    $personaldataOverrides = json_decode($personalDetailsDataCorrection['PersonalDetails'], true);
                    foreach ($candidateMasterData as $key1 => $value1) {
                        if (array_key_exists("$key1", $personaldataOverrides)) {
                            $candidateMasterData[$key1] = $personaldataOverrides["$key1"];
                        }
                    }
                }
            }

            // Correction Window 

            $finalArray = array();
            // foreach ($fieldValidationRule as $data) {
            //     $documentName = strtolower(trim($data['DocumentName']));
            //     if (isset($data['IsRequired']) && $data['IsRequired'] == 1) {
            //         array_push($finalArray, $data);
            //     } //echo $data['DocumentName']."<br>";
            //     if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($candidateMasterData['CastCategoryID']) && $data['IsRequired'] == 0 && ($candidateMasterData['CastCategoryID'] != 1) &&  preg_match("/category/i", strtolower($documentName))) {
            //         array_push($finalArray, $data);
            //     }
            //     if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($candidateMasterData['PhysicalDisability']) && $data['IsRequired'] == 0 && (in_array($candidateMasterData['PhysicalDisability'], [1, 2])) &&  preg_match("/pwd/i", strtolower($documentName))) {
            //         array_push($finalArray, $data);
            //     }
                
            // }

            foreach ($fieldValidationRule as $data) {
                $documentName = strtolower(trim($data['DocumentName']));

                if (isset($data['IsRequired']) && $data['IsRequired'] == 1) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($candidateMasterData['CastCategoryID']) && !empty($candidateMasterData['CastCategoryID']) && $data['IsRequired'] == 0 && ($candidateMasterData['CastCategoryID'] != 1) &&  preg_match("/category/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($candidateMasterData['PhysicalDisability']) && !empty($candidateMasterData['CastCategoryID']) && $data['IsRequired'] == 0 && (in_array($candidateMasterData['PhysicalDisability'], [1, 2]))  &&  preg_match("/pwd/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($artesianDocument['SubjecSpecializationMstID']) && $data['IsRequired'] == 0 && ($artesianDocument['SubjecSpecializationMstID'] == 10074) &&  preg_match("/Artisan/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($twelveDocument['PassStatus12']) && $data['IsRequired'] == 0 && ($twelveDocument['PassStatus12'] == 1) &&  preg_match("/twelve certificate/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                } else if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($twelveDocument['PassStatus12']) && $data['IsRequired'] == 0 && ($twelveDocument['PassStatus12'] == 2) &&  preg_match("/supporting document of twelve/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                }
            }
            $docData = yii::$app->db->createCommand("exec SpCandidateUplodedDoc '$CandidateID'")->queryAll();
            $visiviltyCount = 0;
            if (isset($finalArray) && isset($docData) &&  !empty($finalArray) && !empty($docData)) {

                foreach ($finalArray as $k1 => $v1) {
                    foreach ($docData as $k2 => $v2) {
                        if (isset($v1) && isset($v2['DocumentID']) && !empty($v1['ID']) && !empty($v2['DocumentID']) && $v1['ID'] == $v2['DocumentID']) {
                            //$finalArray[$k1]['UploadDocument'] = $v2['UploadDocument'];

                            $IsFilePresent = Yii::$app->AzureFileUploadComponent->isDocumentPresent($v2['UploadDocument']);
                            if (isset($v2['UploadDocument']) && !empty($v2['UploadDocument']) && !empty($IsFilePresent)) {
                                $documemntPath = yii::$app->params['documentPathAPI'] . '/' . yii::$app->params['containerName'];
                                $finalArray[$k1]['UploadDocument'] = $documemntPath . '/' . $v2['UploadDocument'];
                            } else {
                                $finalArray[$k1]['UploadDocument'] = null;
                            }

                           // $visiviltyCount++;
                        }
                    }
                }
            }

            //Correction Data OverRide:
            if (isset($ApplicationWindowStartStatus, $CorrectionWindowStartStatus) && ($ApplicationWindowStartStatus == 0) && ($CorrectionWindowStartStatus == 1)) {
                $correctionDocDetailsData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                    ->bindValue(':select', 'UploadDocumentDetails')
                    ->bindValue(':input', "WHERE CandidateID=$CandidateID AND ApplicationNumber='$ApplicationNumber' and IsActive=1 ")
                    ->bindValue(':table', 'CandidateCorrectionDataTbl')
                    ->queryOne();
                if (isset($correctionDocDetailsData['UploadDocumentDetails']) && !empty($correctionDocDetailsData['UploadDocumentDetails']) && $this->json_validator($correctionDocDetailsData['UploadDocumentDetails'])) {
                    $docDataArray = json_decode($correctionDocDetailsData['UploadDocumentDetails'], true);
                    if (isset($finalArray) && isset($docDataArray) && !empty($finalArray) && !empty($docDataArray)) {
                        foreach ($finalArray as $k1 => $v1) {
                            foreach ($docDataArray as $k2 => $v2) {
                                if (isset($v1) && isset($v2['DocumentID']) && !empty($v1['ID']) && !empty($v2['DocumentID']) && $v1['ID'] == $v2['DocumentID']) {
                                    $finalArray[$k1]['UploadDocument'] = $v2['UploadDocument'];
                                }
                            }
                        }
                    }
                }
            }

            foreach ($finalArray as $k1 => $v1) {
                if (isset($v1, $v1['UploadDocument']) && !empty($v1) && !empty($v1['UploadDocument'])) {
                    $visiviltyCount++;
                }
            }


            if (isset($visiviltyCount) && isset($finalArray) && !empty($visiviltyCount) && !empty($finalArray) && ($visiviltyCount == count($finalArray))) {

                $ApplicationWindowStartStatus = Yii::$app->ApplicationOpen->Openwindow(); // Check if Application Window Start, 1 = Active, 0= InActive
                $correctionWindowStart = Yii::$app->CorrectionWindow->Openwindow(); // Check if Correction Window Start, 1 = Active, 0= InActive

                $moduleName = 'Document-Details-submit';
                $activityName = 'Next-Button';
                $val = array("applicationWindowStart" => $ApplicationWindowStartStatus, "correctionWindowStart" => $correctionWindowStart, "moduleName" => $moduleName, "activityName" => $activityName);
                Yii::$app->useract->useract($val);

                //Yii::$app->session->setFlash('success', "Document Saved Successfully.");
                Yii::$app->session->setFlash('success', Yii::$app->params['CandidateFormSaveMsg']);
                return $this->redirect(['../final-reviews/index']);
            } else {
                Yii::$app->session->setFlash('error', "somethings went wrong.");
                return $this->redirect(['../document-upload/index']);
            }
            // } else {
            //     Yii::$app->session->setFlash('error', 'You already pay kindly download your application pdf.');
            //     return $this->redirect('../dashboard/index');
            // }
        } else {
            Yii::$app->session->setFlash('error', 'Unauthorised access.');
            return $this->redirect('../site/login');
        }
    }

    protected function uploadDocument($applicationNumber, $selectFile, $tmppath, $type, $name, $apiPath)
    { //die('ok');
        $cfile = curl_file_create($tmppath, $type, $name);
        $curl = curl_init();

        // echo $apiPath; die;

        // $applicationNumber=25;
        curl_setopt_array($curl, array(

            CURLOPT_URL => "$apiPath",
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_SSL_VERIFYPEER => false,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => 'POST',
            CURLOPT_POSTFIELDS => array('applicationnumber' => "$applicationNumber", $selectFile => $cfile),
            CURLOPT_HTTPHEADER => array(
                'ACCESSKEY: 25d55ad283aa400af464c76d713c07ad',
                //'Cookie: _csrf-backend=7764fab458e14d6af71d7f5ad637f58a3f140c494435115a3eecab113d1309b7a%3A2%3A%7Bi%3A0%3Bs%3A13%3A%22_csrf-backend%22%3Bi%3A1%3Bs%3A32%3A%22mvXzLjzPhbTYQ6X4_d7FTFOYbRY1FtKC%22%3B%7D'
            ),
        ));
        $curl_errno = curl_errno($curl);
        $response = curl_exec($curl);
        curl_close($curl);
        // echo"<pre>";
        // print_r($response); die();
        return $response;
    }


    protected function CheckValidImage($ImageTempPath)
    {
        $result = array('status' => 'error', 'message' => 'Something went wrong');
        $subscriptionKey = 'CNjYJ02lWdpfj2nzG77Zrf64Dqg1f978M5LZ6U74ewKPAKEc4PegJQQJ99AKACGhslBXJ3w3AAAKACOGwbuO';
        $endpoint = 'https://azfaceapicore.cognitiveservices.azure.com/face/v1.0/detect';

        // Convert the image to binary data
        $imageData = file_get_contents($ImageTempPath);

        // Set up cURL request to Azure Face API
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $endpoint . '?returnFaceId=true');  // Fixed endpoint URL and added proper query string
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/octet-stream',  // Fixed header format
            'Ocp-Apim-Subscription-Key: ' . $subscriptionKey
        ]);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $imageData);

        // Execute the request
        $response = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);
        if ($httpCode === 200) {
            $faces = json_decode($response, true);
            if (count($faces) === 1) {
                $result['status'] = 'success';
                $result['message'] = "Single face detected.";
            } elseif (count($faces) > 1) {  // Fixed comparison operator for multiple faces
                $result['message'] = "Multiple faces detected.";
            } else {
                $result['message'] = "No face detected.";
            }
        } else {
            $result['message'] = "Error: Unable to detect face. HTTP Status Code $httpCode. Response: $response";
        }
        return $result;
    }


    public function actionImage($FileContent)
    {

        if (isset(Yii::$app->user->identity->ApplicationNumber)) {
            $parmApplicationNo = explode("/", $FileContent);
            if ($parmApplicationNo[0] == Yii::$app->user->identity->ApplicationNumber) {
                $Status = (isset(Yii::$app->params['documentPathAPI'], Yii::$app->params['containerName'], Yii::$app->params['ExamName'], Yii::$app->user->identity->ApplicationNumber)) ? true : false;
                if ($Status) {
                    $imageUrl = Yii::$app->params['documentPathAPI'] . '/' . Yii::$app->params['containerName'] . '/' . Yii::$app->params['ExamName'] . '/' . $FileContent;
                    return $this->redirect($imageUrl);
                } else {
                    return 'Error';
                }
            } else {
                return 'Error';
            }
        } else {
            return 'Error';
        }
    }


    public function actionDownloadFile($FileContent)
    {

        if (isset(Yii::$app->user->identity->ApplicationNumber)) {
            $parmApplicationNo = explode("/", $FileContent);
            if ($parmApplicationNo[0] == Yii::$app->user->identity->ApplicationNumber) {
                $Status = (isset(Yii::$app->params['documentPathAPI'], Yii::$app->params['containerName'], Yii::$app->params['ExamName'], Yii::$app->user->identity->ApplicationNumber)) ? true : false;
                if ($Status) {
                    $imageUrl = Yii::$app->params['documentPathAPI'] . '/' . Yii::$app->params['containerName'] . '/' . Yii::$app->params['ExamName'] . '/' . $FileContent;
                    return $this->redirect($imageUrl);
                } else {
                    return 'Error';
                }
            } else {
                return 'Error';
            }
        } else {
            return 'Error';
        }
    }

    protected function json_validator($data)
    {
        if (!empty($data)) {
            return is_string($data) &&
                is_array(json_decode($data, true)) ? true : false;
        }
        return false;
    }
}
