<?php

namespace app\modules\application\controllers;

use app\modules\application\models\ExamCenterDetails;
use yii;
use yii\filters\AccessControl;
use yii\filters\VerbFilter;
use yii\helpers\ArrayHelper;
use yii\web\Controller;

class ExamCenterController extends Controller
{
    /** 
     * @inheritDoc
     */
    public function behaviors()
    {
        return array_merge(
            parent::behaviors(),
            [
                'access' => [
                    'class' => AccessControl::class,
                    'rules' => [
                        [
                            'actions' => [
                                'logout', 'index', 'captcha', 'course', 'age-candidate', 'age-candidate-ajax',
                                'state-cities',
                            ],
                            'allow' => true,
                            'roles' => ['@'],
                        ],
                    ],
                ],
                'verbs' => [
                    'class' => VerbFilter::className(),
                    'actions' => [
                        'delete' => ['POST'],
                    ],
                ],
            ]
        );
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => \yii\web\ErrorAction::class,
            ],
            'captcha' => [
                'class' => 'common\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

    /**
     * Exam Center
     *
     */
    public function actionIndex()
    {

        // $applicationWindowStart = Yii::$app->ApplicationOpen->Openwindow(); // Check if Application Window Start, 1 = Active, 0= InActive
        // $correctionWindowStart = Yii::$app->CorrectionWindow->Openwindow(); // Check if Correction Window Start, 1 = Active, 0= InActive


        $applicationStatus = Yii::$app->ApplicationOpen->Openwindow();
        $correctionStatus = Yii::$app->CorrectionWindow->Openwindow();

        $isCandidateAllowCorrection = Yii::$app->CheckCorrectionAndApplicationStatus->CheckStatus($applicationStatus, $correctionStatus);

        if (isset($isCandidateAllowCorrection, $isCandidateAllowCorrection['status'], $isCandidateAllowCorrection['msg']) && !empty($isCandidateAllowCorrection) && ($isCandidateAllowCorrection['status'] == 0) && !empty($isCandidateAllowCorrection['msg'])) {
            Yii::$app->session->setFlash('error', $isCandidateAllowCorrection['msg']);
            return $this->redirect(['../dashboard/index']);
        }


        // return $this->redirect(['../dashboard/index']);
        // die();
        //check point
        // if (!yii::$app->ApplicationOpen->Openwindow()) {
        //     return $this->redirect(['/site/login']);
        // }

        // die('asdasd');

        // if (Yii::$app->user->identity->ApplicationFinalSubmit == 1 || Yii::$app->user->identity->PaymentStatus == 1) {
        //     return $this->redirect(['../dashboard/index']);
        // }

        /* check Form Status here And User is exsit*/
        if (isset(yii::$app->user->identity->ID) && !empty(yii::$app->user->identity->ID)) {
            $CandidateID = Yii::$app->user->identity->ID;
        } else {
            Yii::$app->session->setFlash('error', 'Unauthorised access.');
            return $this->redirect('../site/login');
        }

        
        $SubjectSpecializationmstlist = array();
        $CandidateId = Yii::$app->user->identity->ID;
        $ApplicationNumber = Yii::$app->user->identity->ApplicationNumber;
        $getFormStatusCheck = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'ID')
            ->bindValue(':input', 'WHERE CandidateID=' . $CandidateId . ' and ApplicationFormID=2')
            ->bindValue(':table', 'ApplicationFormStatusTbl')
            ->queryOne();
        if (empty($getFormStatusCheck)) {
            Yii::$app->session->setFlash('error', 'please fill your aadhar details');
            return $this->redirect(['../contact/index']);
        }
        $examCenter = new ExamCenterDetails();

        $CourseMstdata = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', 'ID,UPPER(CourseName) as CourseName,CourseCode,OptCourse')
            ->bindValue(':input', 'WHERE IsActive=1 AND OptCourse=1')
            ->bindValue(':orderBy', 'order by CourseName asc')
            ->bindValue(':table', 'CourseMst')
            ->queryAll();
        $CourseMst = (isset($CourseMstdata) && !empty($CourseMstdata)) ? ArrayHelper::map($CourseMstdata, 'ID', 'CourseName') : [];

        $SubjectMstdata = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', "ID,UPPER(SubjectName) AS SubjectName,SubjectCode,ForNet")
            ->bindValue(':input', 'WHERE IsActive=1 AND ForNet=0')
            ->bindValue(':orderBy', 'order by SubjectName asc')
            ->bindValue(':table', 'SubjectMst') 
            ->queryAll();
        $SubjectMstList = (isset($SubjectMstdata) && !empty($SubjectMstdata)) ? ArrayHelper::map($SubjectMstdata, 'ID', 'SubjectName') : [];

        $QuestionPaperLanguageMstData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', "ID,LanguageName")
            ->bindValue(':input', 'WHERE IsActive=1')
            ->bindValue(':orderBy', 'order by LanguageName asc')
            ->bindValue(':table', 'LanguageMst')
            ->queryAll();

        $QuestionPaperLanguageMstList = (isset($QuestionPaperLanguageMstData) && !empty($QuestionPaperLanguageMstData)) ? ArrayHelper::map($QuestionPaperLanguageMstData, 'ID', 'LanguageName') : [];

        $OccupationMstData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', "ID,OccupationName")
            //->bindValue(':input', "WHERE IsActive=1 and OccupationCode!='OTHER'")
            ->bindValue(':input', "WHERE IsActive=1 and OccupationCode NOT IN ('OTHER','NOTAPPLICABLE') ")
            ->bindValue(':orderBy', 'order by OccupationName asc')
            ->bindValue(':table', 'OccupationMst')
            ->queryAll();
        $OccupationMstDataOther = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', "ID,OccupationName")
            //->bindValue(':input', "WHERE IsActive=1 and OccupationCode='OTHER'")
            ->bindValue(':input', "WHERE IsActive=1 and OccupationCode IN ('OTHER') ")
            ->bindValue(':orderBy', 'order by ID asc')
            ->bindValue(':table', 'OccupationMst')
            ->queryAll();
        $OccupationMstList = ArrayHelper::map(array_merge($OccupationMstData, $OccupationMstDataOther), 'ID', 'OccupationName');

        $QualificationMstData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', "ID,QualificationName")
            ->bindValue(':input', "WHERE IsActive=1 and QualificationCode NOT IN ('OTHER','NOTAPPLICABLE') ")
            ->bindValue(':orderBy', 'order by QualificationName asc')
            ->bindValue(':table', 'QualificationMst')
            ->queryAll();
        $QualificationMstDataOther = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', "ID,QualificationName")
            //->bindValue(':input', "WHERE IsActive=1 and QualificationCode='OTHER'")
            ->bindValue(':input', "WHERE IsActive=1 and QualificationCode IN ('OTHER') ")
            ->bindValue(':orderBy', 'order by ID asc')
            ->bindValue(':table', 'QualificationMst')
            ->queryAll();
        $QualificationMstList = ArrayHelper::map(array_merge($QualificationMstData, $QualificationMstDataOther), 'ID', 'QualificationName');

        $SubjectID = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'SubjectID')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateID=' . $CandidateId)
            ->bindValue(':table', 'CandidateApplySubjectTbl')
            ->queryOne();

   
        
            $getDobCandidate = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                ->bindValue(':select', 'DOB')
                ->bindValue(':input', "WHERE ID=$CandidateId")
                ->bindValue(':table', 'CandidateTbl')
                ->queryOne();
                $dobGetCandidate = explode('-',$getDobCandidate['DOB']);
          
             
            if(isset($applicationStatus, $correctionStatus) && ($applicationStatus == 0) && ($correctionStatus == 1)){
                // die('stop');  
                $PersonalDetailsDataArray = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                ->bindValue(':select', 'PersonalDetails')
                ->bindValue(':input', 'WHERE IsActive=1 and CandidateID=' . $CandidateID)
                ->bindValue(':table', 'CandidateCorrectionDataTbl')
                ->queryOne();
                if (isset($PersonalDetailsDataArray, $PersonalDetailsDataArray['PersonalDetails']) && !empty($PersonalDetailsDataArray) && !empty($PersonalDetailsDataArray['PersonalDetails'])) {
                    $PersonalDetailsData = json_decode($PersonalDetailsDataArray['PersonalDetails'], true);

                    if(isset($PersonalDetailsData['DOB']) && !empty($PersonalDetailsData['DOB'])){
                        $dobGetCandidate = explode('-',$PersonalDetailsData['DOB']);
                    }else{
                        Yii::$app->session->setFlash('error', "Something went wrong.");
                        return $this->redirect(['../exam-center/index']);
                    }
                  
                 

                }

            }



        $SubjectSpecializationmstlist = [];

        if (isset($SubjectID['SubjectID']) && ($SubjectID['SubjectID'] !== null)) {

            $SubjectSpecializationmstdata = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
                ->bindValue(':select', 'distinct(ID),SubName')
                ->bindValue(':input', "WHERE IsActive=1 And SubjectMstID =" . $SubjectID['SubjectID'])
                ->bindValue(':table', 'SubjecSpecializationMst')
                ->bindValue('orderBy', 'order by SubName asc')
                ->queryAll();
            $SubjectSpecializationmstOther = [['ID' => 0, 'SubName' => 'OTHER']];
            $SubjectSpecializationmstlist = array_column(array_merge($SubjectSpecializationmstdata, $SubjectSpecializationmstOther), 'SubName', 'ID');
        }

        if ($this->request->isPost) {

            if ($examCenter->load(Yii::$app->request->post()) && $examCenter->validate()) {

                $examResul = Yii::$app->request->post();

                foreach ($examResul['ExamCenterDetails'] as $key => $value) {
                    $examResul['ExamCenterDetails']["$key"] = Yii::$app->SanatizeInput->getInput($value);
                }

                $data = $examResul['ExamCenterDetails'];

                $arrayData = array();
               
                $day= $data['Day'];
                $Month= $data['Month'];
                $Year= $data['Year'];
                $DateOfIssue= $Year.'-'. $Month.'-'. $day;

                
                if (isset($Year) && isset($dobGetCandidate[0])) {
                    if ($Year < $dobGetCandidate[0]) {
                        Yii::$app->session->setFlash('error', 'The issue date of the artisan certificate must be greater than the date of birth.');
                        return $this->redirect(['../exam-center/index']);
                    }
                }

                $DateOfIssuesArtisan = Yii::$app->params['DateOfIssuesArtisan'];
               
                $dateOfIssueInput = new \DateTime($DateOfIssue);
                $dateofIssueFix = new \DateTime($DateOfIssuesArtisan);

                if($dateofIssueFix <= $dateOfIssueInput){
                    Yii::$app->session->setFlash('error', 'The date of issue cannot be greater than 22-11-2024');
                    return $this->redirect(['../exam-center/index']);
                }


                if ($data['SubjectSpecialization'] == 10074  && $data['IsArtisanSonDoughter'] == 0) {
                    Yii::$app->session->setFlash('error', 'You are not eligible for B.Des Artisan.');
                    return $this->redirect(['../exam-center/index']);
                }

                $examCenterArray = array(
                    array('CandidateID' => $CandidateId, 'ApplicationNumber' => $ApplicationNumber, 'ExamCenterStateID' => '0', 'ExamCenterCityID' => $data['FstChoiceForExamCity'], 'ExamCenterPriorty' => 1),
                    array('CandidateID' => $CandidateId, 'ApplicationNumber' => $ApplicationNumber, 'ExamCenterStateID' => '0', 'ExamCenterCityID' => $data['SndChoiceForExamCity'], 'ExamCenterPriorty' => 2),
                    array('CandidateID' => $CandidateId, 'ApplicationNumber' => $ApplicationNumber, 'ExamCenterStateID' => '0', 'ExamCenterCityID' => $data['ThrdChoiceForExamCity'], 'ExamCenterPriorty' => 3),
                    array('CandidateID' => $CandidateId, 'ApplicationNumber' => $ApplicationNumber, 'ExamCenterStateID' => '0', 'ExamCenterCityID' => $data['ForthChoiceForExamCity'], 'ExamCenterPriorty' => 4),
                );

                if ($data['SubjectSpecialization'] == 10074) {
                    $arrayData['IsArtisanSonDoughter'] = (isset($data['IsArtisanSonDoughter']) and !empty($data['IsArtisanSonDoughter'])) ? $data['IsArtisanSonDoughter'] : 0;
                    // $arrayData['ArtisanConfirmation'] = (isset($data['ArtisanConfirmation']) and !empty($data['ArtisanConfirmation'])) ? $data['ArtisanConfirmation'] : 0;
                    $arrayData['TradeOfArtisan'] = (isset($data['TradeOfArtisan']) and !empty($data['TradeOfArtisan'])) ? $data['TradeOfArtisan'] : 0;
                    $arrayData['ArtisanDetails'] = (isset($data['ArtisanDetails']) and !empty($data['ArtisanDetails'])) ? $data['ArtisanDetails'] : null;
                    $arrayData['ArtisanNumber'] = (isset($data['ArtisanNumber']) and !empty($data['ArtisanNumber'])) ? $data['ArtisanNumber'] : null;
                    $arrayData['DateOfIssue'] = (isset($DateOfIssue) and !empty($DateOfIssue)) ? $DateOfIssue : null;
                    $arrayData['ArtisanParentCardNumber'] = (isset($data['ArtisanParentCardNumber']) and !empty($data['ArtisanParentCardNumber'])) ? $data['ArtisanParentCardNumber'] : null;
                } else {
                    $arrayData['IsArtisanSonDoughter'] = null;
                    // $arrayData['ArtisanConfirmation'] = 0;
                    $arrayData['TradeOfArtisan'] = null;
                    $arrayData['ArtisanDetails'] = null;
                    $arrayData['ArtisanNumber'] = null;
                    $arrayData['ArtisanParentCardNumber'] = null;
                }

                if(isset($data['ArtisanDetails'],$data['IsArtisanSonDoughter']) && $data['ArtisanDetails'] == 1 && $data['IsArtisanSonDoughter'] == 1 ){
                    $arrayData['ArtisanParentCardNumber'] = null;
                }

                if(isset($data['ArtisanDetails'],$data['IsArtisanSonDoughter']) && $data['ArtisanDetails'] == 2 && $data['IsArtisanSonDoughter'] == 1 ){
                    $arrayData['ArtisanNumber'] = null;
                }

                $arrayData['CandidateID'] = $CandidateId;
                $arrayData['ApplicationNumber'] = $ApplicationNumber;
                $arrayData['IsActive'] = 1;
                $arrayData['CreatedDate'] = date('Y-m-d H:i:s');
                $arrayData['CandidateIP'] = Yii::$app->request->getUserIP();
                $arrayData['ApplyFor'] = $data['ApplyFor'];
                $arrayData['ApplicationFormID'] = 4;
                $arrayData['SubjectOptedNet'] = '';
                $arrayData['SubjectSpecialization'] = $data['SubjectSpecialization'];
                $arrayData['OtherSubjectSpecialization'] = '';
                $arrayData['QuestionPaperMedium'] = $data['QuestionPaperMedium'];
                $arrayData['FatherGuardianOccupation'] = $data['FatherGuardianOccupation'];
                $arrayData['FatherGuardianQualification'] = $data['FatherGuardianQualification'];
                $arrayData['FatherCandidateRelation'] = 1;
                $arrayData['MotherGuardianOccupation'] = $data['MotherGuardianOccupation'];
                $arrayData['MotherGuardianQualification'] = $data['MotherGuardianQualification'];
                $arrayData['MotherCandidateRelation'] = 2;
                $arrayData['ExamCenter'] = $examCenterArray;
                $arrayData['MphilCourse'] = '';
                $arrayData['UniversityName'] = '';
                $arrayData['AdmissionYear'] = '';
                $arrayData['DegreeCourse'] = '';
                $arrayData['ResultAwaited'] = '';

                $json = json_encode($arrayData);

                //AGE CRITERIA FOR UNDER GRADUATE PROGRAMME.
                if ($data['ApplyFor'] == 1) {
                    if (!$this->actionAgeCandidate($data['ApplyFor'])) {
                        Yii::$app->session->setFlash('error', 'You are not full filling the max age criteria of NIFT.');
                        return $this->redirect(['index']);
                    }
                }

                // die('stoppp');
                //graduate ResultModeG null for security purpose
                if ($data['ApplyFor'] == 1) {
                    Yii::$app->db->createCommand("update CandidateQualificationDetailsTblFinal set  PassStatusG=null WHERE CandidateID=$CandidateId")->execute();
                }



                if (isset($applicationStatus, $correctionStatus) && ($applicationStatus == 1) && ($correctionStatus == 0)) {

                    $sp = '{{AddUpdateExamCenterDetails}}';
                    $response = Yii::$app->db->createCommand("exec $sp @json = :json")
                        ->bindValue(':json', $json)
                        ->execute();
    
                    if (isset($response) && $response == 0) {
                       
                        $moduleName = 'Exam-Center-And-Details';
                         $nextURL='qualification/index';
                         $NextActivityURL = isset($nextURL) ? str_replace("../", "", $nextURL) : 'NA';
                         $activityName = $moduleName . ' '.Yii::$app->params['ActivityDescriptionForControllers']. ' '. $NextActivityURL;
                         $data = array(
                             "applicationWindowStart" => $applicationStatus, "correctionWindowStart" => $correctionStatus,
                             "moduleName" => $moduleName,
                             "activityName" => $activityName
                         );
                         Yii::$app->useract->useract($data);
                         //Activity Log END
                         
                         Yii::$app->session->setFlash('success', 'Exam center details saved successfully.');
                         return $this->redirect(['../qualification/index']);
    
                    } else {
                        Yii::$app->session->setFlash('error', 'Something went wrong.'); 
                        return $this->redirect(['../exam-center/index']);
                    }


                }else if (isset($applicationStatus, $correctionStatus) && ($applicationStatus == 0) && ($correctionStatus == 1)) {

                    $CandidateIP = Yii::$app->masterdata->getCandidateIP();

                    // echo "CandidateId:".$CandidateId;
                    // echo "ApplicationNumber:".$ApplicationNumber;
                    // echo "CandidateIP:".$CandidateIP;

                    // echo "json".$json; die();

                    $sp3 = '{{%saveUpdateCorrectionWindowData}}';
                    $responseCorrection = Yii::$app->db->createCommand("exec $sp3 :candidateID,:ApplicationNumber,:jsonData,:fieldname,:tablename,:currentTime,:candidateIP")
                        ->bindValue(':candidateID', $CandidateId)
                        ->bindValue(':ApplicationNumber', $ApplicationNumber)
                        ->bindValue(':jsonData', $json)
                        ->bindValue(':fieldname', 'ExamCentreDetails')
                        ->bindValue(':tablename', 'CandidateCorrectionDataTbl')
                        ->bindValue(':currentTime', date('Y-m-d H:i:s'))
                        ->bindValue(':candidateIP', $CandidateIP)
                        ->execute();

               
                    if (isset($responseCorrection) && $responseCorrection == 0) {

                        $moduleName = 'Exam-Center-And-Details';
                        $nextURL='qualification/index';
                        $NextActivityURL = isset($nextURL) ? str_replace("../", "", $nextURL) : 'NA';
                        $activityName = $moduleName . ' '.Yii::$app->params['ActivityDescriptionForControllers']. ' '. $NextActivityURL;
                        $data = array(
                            "applicationWindowStart" => $applicationStatus, "correctionWindowStart" => $correctionStatus,
                            "moduleName" => $moduleName,
                            "activityName" => $activityName
                        );
                        Yii::$app->useract->useract($data);
                        //Activity Log END
                        
                        Yii::$app->session->setFlash('success', Yii::$app->params['CandidateFormSaveMsg']);
                        return $this->redirect(['../qualification/index']);

            
                    } else {
                        Yii::$app->session->setFlash('error', 'Something went wrong.');
                        return $this->redirect(['../exam-center/index']);
                    }

                }
             
            } else {
                // echo "<pre>";
                // print_r($examCenter->getErrors());
                // die;
                $examCenter->loadDefaultValues();
            }
        }




        $SubjectSpecializationID = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', '*')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateID=' . $CandidateId)
            ->bindValue(':table', 'CandidateApplySubjectTbl')
            ->queryOne();

        $examDetails = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'ExamCenterCityID,ExamCenterStateID,ExamCenterPriorty')
            ->bindValue(':input', 'WHERE CandidateID=' . $CandidateId . " order By ExamCenterPriorty ASC")
            ->bindValue(':table', 'CandidateChoiceExamCenterTbl')
            ->queryAll();
        // $FstCity = [];
        // $SndCity = [];
        // $ThrdCity = [];
        // $ForthCity = [];
        // echo "<pre>"; print_r($examDetails); die;
        if (!empty($examDetails)) {
            $examCenter->FstChoiceForExamCity = $examDetails[0]['ExamCenterCityID'];
            $examCenter->SndChoiceForExamCity = $examDetails[1]['ExamCenterCityID'];
            $examCenter->ThrdChoiceForExamCity = $examDetails[2]['ExamCenterCityID'];
            $examCenter->ForthChoiceForExamCity = $examDetails[3]['ExamCenterCityID'];
            // $examCenter->FstChoiceForExamState = $examDetails[0]['ExamCenterStateID'];
            // $examCenter->SndChoiceForExamState = $examDetails[1]['ExamCenterStateID'];
            // $examCenter->ThrdChoiceForExamState = $examDetails[2]['ExamCenterStateID'];
            // $examCenter->ForthChoiceForExamState = $examDetails[3]['ExamCenterStateID'];

            // if ($SubjectSpecializationID['IsArtisanSonDoughter'] == 1 && $SubjectSpecializationID['SubjecSpecializationMstID'] == 10074) {
            //     $FstCity = Yii::$app->masterdata->getChoiceStateCityCampus(1);
            //     $SndCity = Yii::$app->masterdata->getChoiceStateCityCampus(1);
            //     $ThrdCity = Yii::$app->masterdata->getChoiceStateCityCampus(1);
            //     $ForthCity = Yii::$app->masterdata->getChoiceStateCityCampus(1);
            // } else {
            //     $FstCity = Yii::$app->masterdata->getChoiceStateCity(@$examDetails[0]['ExamCenterStateID']);
            //     $SndCity = Yii::$app->masterdata->getChoiceStateCity(@$examDetails[1]['ExamCenterStateID']);
            //     $ThrdCity = Yii::$app->masterdata->getChoiceStateCity(@$examDetails[2]['ExamCenterStateID']);
            //     $ForthCity = Yii::$app->masterdata->getChoiceStateCity(@$examDetails[3]['ExamCenterStateID']);
            // }
        }

        //echo "<pre>"; print_r($examDetails);print_r($examCenter); die;


        $StateNameData = Yii::$app->db->createCommand("exec candidateStateSp :candidate_id")
            ->bindValue(':candidate_id', $CandidateId)
            ->queryAll();
        $StateNameDataCampus = [['ID' => 999, 'StateName' => 'Campus']];
        $StateNameList = ArrayHelper::map(array_merge($StateNameData, $StateNameDataCampus), 'ID', 'StateName');
        //  $StateNameList = ArrayHelper::map($StateNameData, 'ID', 'StateName');

        $ApplyForID = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'ApplyCourseID')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateID=' . $CandidateId)
            ->bindValue(':table', 'CandidateApplyCourseTbl')
            ->queryOne();
        $LanguageID = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'LanguageID')
            ->bindValue(':input', 'WHERE IsActive=1 and ID=' . $CandidateId)
            ->bindValue(':table', 'CandidateTbl')
            ->queryOne();
        $fatherQualification = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'QualificationCodeID')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateRelationID=1 and CandidateID=' . $CandidateId)
            ->bindValue(':table', 'ParentGardienQualificationTbl')
            ->queryOne();
        $fatherOccupation = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'OccupationCode')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateRelation=1 and CandidateID=' . $CandidateId)
            ->bindValue(':table', 'ParentGardienOccupationTbl')
            ->queryOne();
        $motherQualification = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'QualificationCodeID')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateRelationID=2 and CandidateID=' . $CandidateId)
            ->bindValue(':table', 'ParentGardienQualificationTbl')
            ->queryOne();
        $motherOccupation = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'OccupationCode')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateRelation=2 and CandidateID=' . $CandidateId)
            ->bindValue(':table', 'ParentGardienOccupationTbl')
            ->queryOne();

        $MphilCourseData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', '*')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateID=' . $CandidateId)
            ->bindValue(':table', 'CandidateExamCenterOtherDetailsTbl')
            ->queryOne();

        if (isset($SubjectID['SubjectID']) && !empty($SubjectID['SubjectID'])) {
            $examCenter->SubjectOptedNet = $SubjectID['SubjectID'];
        }

        if (isset($SubjectSpecializationID['SubjecSpecializationMstID'])) {
            $examCenter->SubjectSpecialization = $SubjectSpecializationID['SubjecSpecializationMstID'];
        }
        if (isset($SubjectSpecializationID['OtherSubjectSpecialization']) && !empty($SubjectSpecializationID['OtherSubjectSpecialization'])) {
            $examCenter->OtherSubjectSpecialization = $SubjectSpecializationID['OtherSubjectSpecialization'];
        }
        if (isset($SubjectSpecializationID['SubjecSpecializationMstID']) && $SubjectSpecializationID['SubjecSpecializationMstID'] == 10074 && isset($SubjectSpecializationID['IsArtisanSonDoughter'])) {
            $examCenter->IsArtisanSonDoughter = $SubjectSpecializationID['IsArtisanSonDoughter'];
            // $examCenter->ArtisanConfirmation = $SubjectSpecializationID['ArtisanConfirmation'];
            $examCenter->TradeOfArtisan = $SubjectSpecializationID['TradeOfArtisan'];
            $examCenter->DateOfIssue = $SubjectSpecializationID['DateOfIssue'];
        }
        if (isset($SubjectSpecializationID['ArtisanDetails']) && !empty($SubjectSpecializationID['ArtisanDetails'])) {
            $examCenter->ArtisanDetails = $SubjectSpecializationID['ArtisanDetails'];
        }
        if (isset($SubjectSpecializationID['ArtisanNumber']) && !empty($SubjectSpecializationID['ArtisanNumber'])) {
            $examCenter->ArtisanNumber = $SubjectSpecializationID['ArtisanNumber'];
        }
        if (isset($SubjectSpecializationID['ArtisanParentCardNumber']) && !empty($SubjectSpecializationID['ArtisanParentCardNumber'])) {
            $examCenter->ArtisanParentCardNumber = $SubjectSpecializationID['ArtisanParentCardNumber'];
        }

        if (isset($ApplyForID['ApplyCourseID']) && !empty($ApplyForID['ApplyCourseID'])) {
            $examCenter->ApplyFor = $ApplyForID['ApplyCourseID'];
        }
        if (isset($LanguageID['LanguageID']) && !empty($LanguageID['LanguageID'])) {
            $examCenter->QuestionPaperMedium = $LanguageID['LanguageID'];
        }
        if (isset($fatherOccupation['OccupationCode']) && !empty($fatherOccupation['OccupationCode'])) {
            $examCenter->FatherGuardianOccupation = $fatherOccupation['OccupationCode'];
        }
        if (isset($fatherQualification['QualificationCodeID']) && !empty($fatherQualification['QualificationCodeID'])) {
            $examCenter->FatherGuardianQualification = $fatherQualification['QualificationCodeID'];
        }
        if (isset($motherOccupation['OccupationCode']) && !empty($motherOccupation['OccupationCode'])) {
            $examCenter->MotherGuardianOccupation = $motherOccupation['OccupationCode'];
        }
        if (isset($motherQualification['QualificationCodeID']) && !empty($motherQualification['QualificationCodeID'])) {
            $examCenter->MotherGuardianQualification = $motherQualification['QualificationCodeID'];
        }

        /* Add Other Details  */
        if (isset($MphilCourseData['MphilCourse']) && $MphilCourseData['MphilCourse'] !== null) {
            $examCenter->MphilCourse = $MphilCourseData['MphilCourse'];
        }
        if (isset($MphilCourseData['DegreeCourse']) && $MphilCourseData['DegreeCourse'] !== null) {
            $examCenter->DegreeCourse = $MphilCourseData['DegreeCourse'];
        }
        if (isset($MphilCourseData['ResultAwaited']) && $MphilCourseData['ResultAwaited'] !== null) {
            $examCenter->ResultAwaited = $MphilCourseData['ResultAwaited'];
        }
        if (isset($MphilCourseData['UniversityName']) && !empty($MphilCourseData['UniversityName'])) {
            $examCenter->UniversityName = $MphilCourseData['UniversityName'];
        }
        if (isset($MphilCourseData['AdmissionYear']) && !empty($MphilCourseData['AdmissionYear'])) {
            $examCenter->AdmissionYear = $MphilCourseData['AdmissionYear'];
        }

        if (isset($examCenter->ApplyFor) && !empty($examCenter->ApplyFor)) {
            $CourseApplywith = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
                ->bindValue(':select', 'ID,CourseName')
                ->bindValue(':input', "WHERE IsActive=1 and ID=10074 and CourseType=$examCenter->ApplyFor")
                ->bindValue(':orderBy', 'order by CourseName asc')
                ->bindValue(':table', 'CourseMst')
                ->queryAll();
            $SubjectSpecializationmstlist = (isset($CourseApplywith) && !empty($CourseApplywith)) ? ArrayHelper::map($CourseApplywith, 'ID', 'CourseName') : [];
        }

        $StateCityData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', 'distinct(ID),CityName')
            ->bindValue(':input', "WHERE isCampus=1")
            ->bindValue(':table', 'CityMst')
            ->bindValue('orderBy', 'order by CityName asc')
            ->queryAll();
        
        $StateCityData = (isset($StateCityData) && !empty($StateCityData)) ? ArrayHelper::map($StateCityData, 'ID', 'CityName') : [];



        // echo "<pre>";print_r($examCenter); die();
        // echo "<br><br><br><br><br><br><br>";

        if (isset($applicationStatus, $correctionStatus) && ($applicationStatus == 0) && ($correctionStatus == 1)) {

            // $ExamCenterDetailsDataArray = Yii::$app->masterdata->getCorrectionDataByCol('ExamCentreDetails');

            $ExamCenterDetailsDataArray = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'ExamCentreDetails')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateID=' . $CandidateId)
            ->bindValue(':table', 'CandidateCorrectionDataTbl')
            ->queryOne();
        
            if (isset($ExamCenterDetailsDataArray, $ExamCenterDetailsDataArray['ExamCentreDetails']) && !empty($ExamCenterDetailsDataArray) && !empty($ExamCenterDetailsDataArray['ExamCentreDetails']) && $this->json_validator($ExamCenterDetailsDataArray['ExamCentreDetails'])) {

                $ExamCenterDetailsData = json_decode($ExamCenterDetailsDataArray['ExamCentreDetails'], true);

                // echo "<pre>"; print_r($ExamCenterDetailsData); die();


                // echo "<pre>"; print_r($ExamCenterDetailsData);

                // foreach ($ExamCenterDetailsData as $key => $values) {

                //     // echo "asdasdas<pre>"; print_r($values); 
                //     // echo $key."<pre>"; 

                //     // $unsetArray = array('IsActive', 'CreatedDate', 'ApplicationFormID', 'CandidateID', 'verifyCode');
                //     // if (isset($key, $unsetArray) && is_array($unsetArray) && in_array($key, $unsetArray)) {
                //     //     unset($ExamCenterDetailsData["$key"]);
                //     //     continue;
                //     // }
                //     // if(isset($key) && ($key != 'CandidateIP') && ($key != 'CreatedDate')){
                //         //    $examCenter->{$key} = $values;
                //     // }
                 
                // }

                $examCenter->FatherGuardianOccupation = $ExamCenterDetailsData['FatherGuardianOccupation'];
                $examCenter->FatherGuardianQualification = $ExamCenterDetailsData['FatherGuardianQualification'];
                $examCenter->MotherGuardianOccupation = $ExamCenterDetailsData['MotherGuardianOccupation'];
                $examCenter->MotherGuardianQualification = $ExamCenterDetailsData['MotherGuardianQualification'];


                $examCenter->ApplyFor = $ExamCenterDetailsData['ApplyFor'];
                $examCenter->SubjectSpecialization = $ExamCenterDetailsData['SubjectSpecialization'];
                $examCenter->QuestionPaperMedium = $ExamCenterDetailsData['QuestionPaperMedium'];
                $examCenter->IsArtisanSonDoughter = $ExamCenterDetailsData['IsArtisanSonDoughter'];
                $examCenter->ArtisanDetails = $ExamCenterDetailsData['ArtisanDetails'];


                $examCenter->ArtisanNumber = $ExamCenterDetailsData['ArtisanNumber'];
                $examCenter->ArtisanParentCardNumber = $ExamCenterDetailsData['ArtisanParentCardNumber'];
                $examCenter->TradeOfArtisan = $ExamCenterDetailsData['TradeOfArtisan'];

                $arrayExamState=[];
                $arrayExamState = $ExamCenterDetailsData['ExamCenter'];
         
            $CandidateExamCenter = $arrayExamState;
            $FstCity = [];
            $SndCity = [];
            $ThrdCity = [];
            $ForthCity = [];

            if (isset($CandidateExamCenter) && !empty($CandidateExamCenter)) {  
                        
                $examCenter->FstChoiceForExamCity = @$CandidateExamCenter[0]['ExamCenterCityID'];
                $examCenter->SndChoiceForExamCity = @$CandidateExamCenter[1]['ExamCenterCityID'];
                $examCenter->ThrdChoiceForExamCity = @$CandidateExamCenter[2]['ExamCenterCityID'];
                $examCenter->ForthChoiceForExamCity = @$CandidateExamCenter[3]['ExamCenterCityID'];
             }
        }


         
        
         }
        //  die('stop');
           
        // echo "<pre>";print_r($examCenter); die;


        return $this->render('ExamCenterDetailsForm', [
            'model' => $examCenter,
            'CourseMst' => $CourseMst,
            'SubjectMst' => $SubjectMstList,
            'SubjectSpecializationmst' => $SubjectSpecializationmstlist,
            'QuestionPaperLanguageMst' => $QuestionPaperLanguageMstList,
            'StateMst' => $StateNameList,
            'backLink' => 'personal/index',
            'OccupationMst' => $OccupationMstList,
            'QualificationMst' => $QualificationMstList,
            'DobDate' => Yii::$app->masterdata->dayArray(),
            'DobMonth' => Yii::$app->masterdata->monthArray(),
            'DobYear' => Yii::$app->masterdata->yearArrayArtisan(),
            'StateCityData'=>$StateCityData,
            'correctionWindowStart'=>$correctionStatus,
        ]);
    }

    public function getExamCenterQPData($ID)
    {
        //        $DB = Yii::$app->session->get('NewDB');
        //        if (empty($DB)) {
        //            return $this->redirect(['/site/login']);
        //        }
        $CandidatesubCoursedata['subjectCourse'] = \Yii::$app->db->createCommand("exec ExamcenterEditviewCSL_Sp :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

        $CandidatesubCoursedata['centerChoice'] = \Yii::$app->db->createCommand("exec ExamcenterEditviewCanddateChoice_Sp :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

        $CandidatesubCoursedata['parentOccupation'] = \Yii::$app->db->createCommand("exec ExamcenterEditviewPGOccupationSp :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

        $CandidatesubCoursedata['parentQualification'] = \Yii::$app->db->createCommand("exec ExamcenterEditviewPGQualification_Sp :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

        if ($CandidatesubCoursedata !== null) {
            return $CandidatesubCoursedata;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }

    //    public function actionCitylist()
    //    {
    //        // print_r(Yii::$app->request->post());die();
    //
    //        $id = Yii::$app->request->post('id');
    //        $selectCity = Yii::$app->request->post('selectCity') ? Yii::$app->request->post('selectCity') : '';
    //        echo "<option value=''>--Select City--</option>";
    //        $CityMstListData = CityMst::find()->select('CityMst.ID,CityMst.CityName')
    //            ->leftJoin('AdminExamCenterMst', 'AdminExamCenterMst.StateID=CityMst.StateID')
    //            ->where(['AdminExamCenterMst.StateID' => $id, 'AdminExamCenterMst.IsActive' => 1])
    //            ->orderBy('CityMst.CityName asc')
    //            ->all();
    //
    //        if (!empty($CityMstListData)) {
    //            foreach ($CityMstListData as $row) {
    //                $select = '';
    //                if (isset($selectCity) && !empty($selectCity)) {
    //                    if ($selectCity == $row['ID']) {
    //                        $select = 'selected';
    //                    }
    //                }
    //                echo "<option value='" . $row['ID'] . "' $select>" . $row['CityName'] . "</option>";
    //            }
    //        }
    //    }

    public function actionStateCities()
    {
        //        $DB = Yii::$app->session->get('NewDB');
        //        if (empty($DB)) {
        //            return $this->redirect(['/site/login']);
        //        }
        $state_id = Yii::$app->request->post('state_id');
        $iscampus = Yii::$app->request->post('iscampus');
        $data = "<option value=''>--Select City--</option>";
        if ($state_id == null) {
            return $data;
        }
        if ($iscampus == 1) {
            $where = "WHERE IsActive=1 AND IsCampus=$iscampus";
        } else {
            $where = "WHERE IsActive=1 and StateID=$state_id";
        }
        //$StateCityData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
        //                                    ->bindValue(':select', 'CityMst.ID,CityMst.CityName')
        //                                    ->bindValue(':input', "left join AdminExamCenterMst on AdminExamCenterMst.StateID=CityMst.StateID  WHERE AdminExamCenterMst.IsActive=1 and AdminExamCenterMst.StateID=$state_id group by CityMst.ID,CityMst.CityName")
        //                                    ->bindValue(':table', 'CityMst')
        //                                    ->bindValue('orderBy', 'order by CityMst.CityName asc')
        //                                    ->queryAll();
        $StateCityData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', 'distinct(ID),CityName')
            ->bindValue(':input', $where)
            ->bindValue(':table', 'CityMst')
            ->bindValue('orderBy', 'order by CityName asc')
            ->queryAll();
        if (isset($StateCityData) && !empty($StateCityData)) {
            foreach ($StateCityData as $row) {
                $data .= "<option value='" . $row['ID'] . "'>" . $row['CityName'] . "</option>";
            }
        }
        return $data;
    }

    public function actionCourse()
    {
        //        $DB = Yii::$app->session->get('NewDB');
        //        if (empty($DB)) {
        //            return $this->redirect(['/site/login']);
        //        }
        $apply_id = Yii::$app->request->post('apply_id');
        $data = "<option value=''>--Select--</option>";
        if ($apply_id == null) {
            return $data;
        }
        // $CourseData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
        //     ->bindValue(':select', 'distinct(ID),CourseName')
        //     ->bindValue(':input', "WHERE IsActive=1 and ID=10074 and CourseType=$apply_id")
        //     ->bindValue(':table', 'CourseMst')
        //     ->bindValue('orderBy', 'order by CourseName asc')
        //     ->queryAll();
        // }
        $CourseData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
            ->bindValue(':select', 'distinct(ID),CourseName')
            ->bindValue(':input', "WHERE IsActive=1 and CourseType=$apply_id")
            ->bindValue(':table', 'CourseMst')
            ->bindValue('orderBy', 'order by CourseName asc')
            ->queryAll();
        if (isset($CourseData) && !empty($CourseData)) {
            foreach ($CourseData as $row) {
                $data .= "<option value='" . $row['ID'] . "'>" . $row['CourseName'] . "</option>";
            }
        }
        return $data;
    }

    public function actionGetAgeAsOnDate($id)
    {
        //        $DB = Yii::$app->session->get('NewDB');
        //        if (empty($DB)) {
        //            return $this->redirect(['/site/login']);
        //        }
        $courseData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'CourseCode')
            ->bindValue(':input', 'WHERE IsActive=1 AND ID=' . $id)
            ->bindValue(':table', 'CourseMst')
            ->queryOne();
        if (isset($courseData) && !empty($courseData)) {
            $apply_course_code = $courseData['CourseCode'];
            if ($apply_course_code == 'C001') {
                $cand_dob = date('Y-m-d', strtotime(Yii::$app->user->identity->DOB));
                $max_age_as_on_time_of_registration_date = date('Y-m-d', strtotime(yii::$app->params['MAX_AGE_AS_ON_TIME_OF_REGISTRATION_DATE']));
                $cand_age_calculated_as_on_date = Yii::$app->masterdata->ageCalculatorAsOnGivendate($cand_dob, $max_age_as_on_time_of_registration_date);
                $max_age_29 = yii::$app->params['MAX_AGE_AS_ON_DATE_FOR_ANY'];
                $checkMaxAgeAsOnDate_29 = Yii::$app->masterdata->checkAgeAsOnDate($cand_age_calculated_as_on_date, $max_age_29);

                if ($checkMaxAgeAsOnDate_29) {
                    return 'success';
                } else {
                    return 'error';
                }
            } else {
                return 'success';
            }
        } else {
            return 'error';
        }
    }


    public function actionAgeCandidate($applyfor)
    {
        if (isset($applyfor) && !empty($applyfor) && $applyfor == 1) {

            $candidatePost = $applyfor;

            $result = Yii::$app->AgeCandidateCondition->CandidateAgeCondition($candidatePost);

            if ($result) {
                return true;
            } else {
                return false;
            }
            //die();

        }
    }

    public function actionAgeCandidateAjax()
    {
        if (isset($_POST['Apply_for']) && !empty($_POST['Apply_for']) && $_POST['Apply_for'] == 1) {
            $candidatePost = $_POST['Apply_for'];
            $result = Yii::$app->AgeCandidateCondition->CandidateAgeCondition($candidatePost);
            if ($result) {
                return 1;
            } else {
                return 0;
            }
            //die();
        }
    }

    protected function json_validator($data)
    {
        if (!empty($data)) {
            return is_string($data) &&
                is_array(json_decode($data, true)) ? true : false;
        }
        // print_r("hiiiii");die;
        return false;
    }
}
