<?php

namespace app\modules\application\controllers;

use app\modules\application\models\ExamCenterDetails;
use app\modules\application\models\CandidateTbl;
use app\modules\application\models\ApplicationFormStatusTbl;
use yii\web\Controller;
use yii\filters\VerbFilter;
use yii;
use yii\filters\AccessControl;
use frontend\modules\application\models\DocumentMst;
use frontend\modules\application\models\CandidateDocumentTbl;
use app\modules\application\models\ReviewApplicationForm;
use Codeception\Lib\Di;
use Mpdf\Mpdf;


class FinalReviewsController extends Controller
{
    /**
     * @inheritDoc
     */
    public function behaviors()
    {
        return array_merge(
            parent::behaviors(),
            [
                'access' => [
                    'class' => AccessControl::class,
                    'rules' => [
                        [
                            'actions' => [
                                'logout', 'index', 'aadhardetailsform', 'contactdetailsform',
                                'personaldetailsform', 'postgraduation', 'additional',
                                'document-upload', 'review-application-form', 'citylist',
                                'reviewapplicationform', 'reviewpdf', 'findModel',
                                'findPersonDetailSaveModel', 'findPersonalModel',
                                'passyear', 'resultmode', 'resultmodedistict', 'application-status',
                                'documentUpload', 'fileuploaded', 'examcenterdetailsform', 'examcenterdetailsformlink',
                                'getExamCenterQPData', 'resultmode-distict', 'captcha', 'sendreviewpdf', 'payment-receipt','file-download',
                                'download-form'
                            ],
                            'allow' => true,
                            'roles' => ['@'],
                        ],
                    ],
                ],
                'verbs' => [
                    'class' => VerbFilter::className(),
                    'actions' => [
                        'delete' => ['POST'],
                    ],
                ],
            ]
        );
    }
    
    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => \yii\web\ErrorAction::class,
            ],
            'captcha' => [
                'class' => \yii\captcha\CaptchaAction::class,
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }
    
    public function actionIndex()
    {
        // return $this->redirect(['../dashboard/index']);
        // die();

        // if (!yii::$app->ApplicationOpen->Openwindow()) {
        //     return $this->redirect(['/site/login']);
        // }
       

        $applicationStatus = Yii::$app->ApplicationOpen->Openwindow();
        $correctionStatus = Yii::$app->CorrectionWindow->Openwindow();

        $isCandidateAllowCorrection = Yii::$app->CheckCorrectionAndApplicationStatus->CheckStatus($applicationStatus, $correctionStatus);

        if (isset($isCandidateAllowCorrection, $isCandidateAllowCorrection['status'], $isCandidateAllowCorrection['msg']) && !empty($isCandidateAllowCorrection) && ($isCandidateAllowCorrection['status'] == 0) && !empty($isCandidateAllowCorrection['msg'])) {
            Yii::$app->session->setFlash('error', $isCandidateAllowCorrection['msg']);
            return $this->redirect(['../dashboard/index']);
        }

        // if (Yii::$app->user->identity->ApplicationFinalSubmit == 1 || Yii::$app->user->identity->PaymentStatus == 1) {
        //     return $this->redirect(['../dashboard/index']);
        // }

        
        /* check Form Status here And User is exsit*/  
        if (isset(yii::$app->user->identity->ID) && !empty(yii::$app->user->identity->ID)) {            
            $CandidateID = Yii::$app->user->identity->ID;    
        }else{
            Yii::$app->session->setFlash('error', 'Unauthorised access.');
            return $this->redirect('../site/login');
        }
                
        $personalDetailsFormStatusCheck = $this->checkFormStaus($CandidateID,1);
        if (!isset($personalDetailsFormStatusCheck) && empty($personalDetailsFormStatusCheck)){
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../personal/index']);
        }

        if (isset($personalDetailsFormStatusCheck) && !empty($personalDetailsFormStatusCheck) && $personalDetailsFormStatusCheck['IsComplete'] == 0) {
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../personal/index']);
        }

        // Check status of contactdetailsform $form_id = 2
        $contactDetailsFormStatusCheck = $this->checkFormStaus($CandidateID,2);        
        if (!isset($contactDetailsFormStatusCheck) && empty($contactDetailsFormStatusCheck)){
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../contact/index']);
        }

        if (isset($contactDetailsFormStatusCheck) && !empty($contactDetailsFormStatusCheck) && $contactDetailsFormStatusCheck['IsComplete'] == 0) {
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../contact/index']);
        }

        // Check status of aadhardetailsform $form_id = 3   
        $aadharDetailsFormStatusCheck = $this->checkFormStaus($CandidateID,3);
        if (!isset($aadharDetailsFormStatusCheck) && empty($aadharDetailsFormStatusCheck)){
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../aadhar/index']);
        }

        if (isset($aadharDetailsFormStatusCheck) && !empty($aadharDetailsFormStatusCheck) && $aadharDetailsFormStatusCheck['IsComplete'] == 0) {
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../aadhar/index']);
        }

        // Check status of examcenterdetailsform $form_id = 4
        $examCenterFormStatusCheck = $this->checkFormStaus($CandidateID,4);
        
        if (!isset($examCenterFormStatusCheck) && empty($examCenterFormStatusCheck)){
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../exam-center/index']);
        }
        if (isset($examCenterFormStatusCheck) && !empty($examCenterFormStatusCheck) && $examCenterFormStatusCheck['IsComplete'] == 0) {
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../exam-center/index']);
        }
        // Check status of postgraduation $form_id = 5
        $postgraduationFormStatusCheck = $this->checkFormStaus($CandidateID,5);        
        if (!isset($postgraduationFormStatusCheck) && empty($postgraduationFormStatusCheck)){
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../qualification/index']);
        }

        if (isset($postgraduationFormStatusCheck) && !empty($postgraduationFormStatusCheck) && $postgraduationFormStatusCheck['IsComplete'] == 0) {
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../qualification/index']);
        }


        // Check status of additional $form_id = 6
        // $additionalFormStatusCheck = $this->checkFormStaus($CandidateID,6);         
        // if (!isset($additionalFormStatusCheck) && empty($additionalFormStatusCheck)){
        //     Yii::$app->session->setFlash('success', 'Please Complete this form');
        //     return $this->redirect(['../additional/index']);
        // }
        // if (isset($additionalFormStatusCheck) && !empty($additionalFormStatusCheck) && $additionalFormStatusCheck['IsComplete'] == 0) {
        //     Yii::$app->session->setFlash('success', 'Please Complete this form');
        //     return $this->redirect(['../additional/index']);
        // }

        // Check status of document-upload $form_id = 7
        $documentUploadFormStatusCheck = $this->checkFormStaus($CandidateID,7);
        if (!isset($documentUploadFormStatusCheck) && empty($documentUploadFormStatusCheck)){
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../document-upload/index']);
        }
        if (isset($documentUploadFormStatusCheck) && !empty($documentUploadFormStatusCheck) && $documentUploadFormStatusCheck['IsComplete'] == 0) {
            Yii::$app->session->setFlash('success', 'Please Complete this form');
            return $this->redirect(['../document-upload/index']);
        }


        $getFormStatusCheck = $this->checkFormStaus($CandidateID,7);
        if (!$getFormStatusCheck) {
            return $this->redirect(['../dashboard/index']);
        }
        


        //Check MAX AGE CRITERIA for NIFT:
        if(!Yii::$app->masterdata->checkAgeCriteria()){
            Yii::$app->session->setFlash('error', 'You are not full filling the max age criteria of NIFT.');
            return $this->redirect(['../dashboard/index']);
        }


        $ApplyCourseID = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
        ->bindValue(':select', 'ApplyCourseID')
        ->bindValue(':input', "WHERE IsActive=1 and CandidateID=$CandidateID")
        ->bindValue(':table', 'CandidateApplyCourseTbl')
        ->queryOne();

        if(isset($ApplyCourseID['ApplyCourseID']) && $ApplyCourseID['ApplyCourseID']==2)
        {
            $GraduationCheck = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'PassStatusG')
            ->bindValue(':input', "WHERE CandidateID=$CandidateID")
            ->bindValue(':table', 'CandidateQualificationDetailsTblFinal')
            ->queryOne();

            if(isset($GraduationCheck) && empty($GraduationCheck['PassStatusG']))
            {
                Yii::$app->session->setFlash('success', 'Please Add Graduation Details.');
                return $this->redirect(['../qualification/index']);  
            }
        }
        

        $ReviewexamCenter = new ExamCenterDetails();
        $ReviewApplicationForm = new ReviewApplicationForm();
        $canndidatePaymentStatus =  CandidateTbl::find()->select('PaymentStatus')->where(['ID' => Yii::$app->user->identity->ID])->asArray()->one();


        $ID = yii::$app->user->identity->ID;


        $result = \Yii::$app->db->createCommand("exec  getReviewData :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryOne();

        // echo "<pre>"; print_r($result); die();


        
        // $PersonalDetail = Yii::$app->db->createCommand("exec  getReviewDataPerCandidate :candidate_id")
        //     ->bindValue(':candidate_id', $CandidateID)
        //     ->queryOne();

        //     echo "<pre>"; print_r($PersonalDetail); die();

        // $PersonalDetailCorrection = Yii::$app->db->createCommand("exec  getReviewDataPerCandidateCorrection :candidate_id")
        //     ->bindValue(':candidate_id', $CandidateID)
        //     ->queryOne();
        // if (isset($PersonalDetailCorrection['ApplicationNumber']) && !empty($PersonalDetailCorrection['ApplicationNumber'])) {
        //     $PersonalDetail = $PersonalDetailCorrection;

        // }
        // echo  "<pre>"; print_r( $PersonalDetail ); die();





        // echo "<pre>"; print_r($result); die();
            
        // code for artisan
        // if ($result['SubjecSpecializationMstID'] != 10074) {
        //     return $this->redirect(['../dashboard/index']);
        // }
        // code for artisan
        
        /*Exam center */
        $examcdataresult = \Yii::$app->db->createCommand("exec  getReviewExamcenterData :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

        // echo  "<pre>"; print_r( $examcdataresult ); die();

        $examcdataresultCampus = \Yii::$app->db->createCommand("exec  getReviewExamcenterDataCampus :candidate_id")
                ->bindValue(':candidate_id', $ID)
                ->queryAll();
    //    echo"<pre>";print_r($examcdataresultCampus);die;



        $ParentOcupdataresult = \Yii::$app->db->createCommand("exec  getReviewExamcenterparnOcupData :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

            // echo"<pre>";print_r($ParentOcupdataresult);die;


        $ParentQualifdataresult = \Yii::$app->db->createCommand("exec  getReviewExamcenterparnQualifData :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

        //   echo"<pre>";print_r($ParentQualifdataresult);die;

        




        $candidateUploadDocument = \Yii::$app->db->createCommand("exec  SpCandidateUplodedDoc :candidate_id")
               ->bindValue(':candidate_id', $ID)
               ->queryAll();
        $fieldValidationRule = $this->getAllDocumentValidation();
        $buttonVisible = 0;
        $error_array = [];

        $twelveDocument = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                    ->bindValue(':select', 'PassStatus12')
                    ->bindValue(':input', 'WHERE IsActive=1 and CandidateID='.$ID)
                    ->bindValue(':table', 'CandidateQualificationDetailsTblFinal')->queryOne();

        

            $stateStatus = Yii::$app->StateDistrict->StateDistrictMatchCheck(yii::$app->user->identity->ID);
            //echo "<pre>"; print_r($stateStatus); die;
           if (isset($stateStatus) && !empty($stateStatus)) {
               if (isset($stateStatus['status']) && empty($stateStatus['message']) && !empty($stateStatus['status'])) {
                   $error_array['status'] = $stateStatus['status'];
                   array_push($error_array, $stateStatus['message']);
                   $buttonVisible = 1;
               } else if (isset($stateStatus['status']) && !empty($stateStatus['message'])) {
                   $error_array['status'] = $stateStatus['status'];
                   array_push($error_array, $stateStatus['message']);
               } else {
                   $error_array['status'] = $stateStatus['status'];
                   array_push($error_array, $stateStatus['message']);
               }
           }

        
 
        $finalArray = array();
        foreach ($fieldValidationRule as $data) {
            $documentName = strtolower(trim($data['DocumentName']));
            if (isset($data['IsRequired']) && $data['IsRequired'] == 1) {
                array_push($finalArray, $data);
            }
            if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['CastCategoryID']) && $data['IsRequired'] == 0 && ($result['CastCategoryID'] != 1) &&  preg_match("/category/i", strtolower($documentName))) {
                array_push($finalArray, $data);
            }
            if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['PhysicalDisability']) && $data['IsRequired'] == 0 && ($result['PhysicalDisability'] == 1) &&  preg_match("/pwd/i", strtolower($documentName))) {
                array_push($finalArray, $data);
            }

            if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['NeedScribe']) && $data['IsRequired'] == 0 && ($result['PhysicalDisability'] == 1 && $result['NeedScribe'] == 2) &&  preg_match("/scribe/i", strtolower($documentName))) {
                array_push($finalArray, $data);
            }
            
            if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['SubjecSpecializationMstID']) && $data['IsRequired'] == 0 && ($result['SubjecSpecializationMstID'] == 10074) &&  preg_match("/Artisan/i", strtolower($documentName))) {
                array_push($finalArray, $data);
            }    
        }



    //    echo "<pre>";
    //    print_r($finalArray);
    //    die;

        if (isset($finalArray) && isset($candidateUploadDocument) &&  !empty($finalArray) && !empty($candidateUploadDocument)) {
           $visiviltyCount = 0;
           foreach ($finalArray as $k1 => $v1) {
               foreach ($candidateUploadDocument as $k2 => $v2) {
                   if (isset($v1) && isset($v2['DocumentID']) && !empty($v1['ID']) && !empty($v2['DocumentID']) && $v1['ID'] == $v2['DocumentID']) {
                       $finalArray[$k1]['UploadDocument'] = $v2['UploadDocument'];
                       $visiviltyCount++;
                   }
               }
           }
        }


        $nextbuttonvisible = 0;
        if (isset($visiviltyCount) && isset($finalArray) && !empty($visiviltyCount) && !empty($finalArray) && ($visiviltyCount == count($finalArray))) {
            $nextbuttonvisible = 1;
        }

        if (Yii::$app->request->post()) {
            if ($ReviewApplicationForm->load(Yii::$app->request->post()) && $ReviewApplicationForm->validate()) {
                $data = Yii::$app->request->post();
                $candidateID = yii::$app->user->identity->ID;
                $confirmationArray['CandidateID'] = $candidateID;
                $confirmationArray['IsCheckedName'] = $data['ReviewApplicationForm']['IsCheckedName'];
                $confirmationArray['IsCheckedDOB'] = $data['ReviewApplicationForm']['IsCheckedDOB'];
                $confirmationArray['IsCheckedFatherName'] = $data['ReviewApplicationForm']['IsCheckedFatherName'];
                $confirmationArray['IsCheckedMotherName'] = $data['ReviewApplicationForm']['IsCheckedMotherName'];
                $confirmationArray['IsCheckedGender'] = $data['ReviewApplicationForm']['IsCheckedGender'];
                $confirmationArray['ApplicationFInalSubmit'] = 1;
                $confirmationArray['ApplicationSubmitDate'] = date('Y-m-d H:i:s');
                $confirmationArray['IsConfirm'] = $data['ReviewApplicationForm']['IsConfirm'];
                $confirmationArray['ApplicationFormID'] = 8;
                $json = json_encode($confirmationArray);
                $sp = '{{SaveFinalformSubmit}}';
                $response = Yii::$app->db->createCommand("exec $sp @json = :json")
                                                ->bindValue(':json', $json)
                                                ->queryOne();
              
                if(isset($response) && !empty($response) && isset($response['ID']) && !empty($response['ID'])) {
                    //yii::$app->db->createCommand("exec FinalSubmitionfee :candidate_id")
                    //                        ->bindValue(':candidate_id', $ID)
                    //                        ->execute();
                    // userAct insert
                  
                    //Activity Log START
                    $moduleName = 'Final-Submit';
                    $nextURL = 'payment/index';
                    $NextActivityURL = isset($nextURL) ? str_replace("../", "", $nextURL) : 'NA';
                    $activityName = $moduleName . ' ' . Yii::$app->params['ActivityDescriptionForControllers'] . ' ' . $NextActivityURL;
                    $data = array(
                        "applicationWindowStart" => $applicationStatus,
                        "correctionWindowStart" => $correctionStatus,
                        "moduleName" => $moduleName,
                        "activityName" => $activityName
                    );
                    Yii::$app->useract->useract($data);
                    //Activity Log END

                    Yii::$app->session->setFlash('success', 'Your Application Form Submitted Successfully');
                    return $this->redirect(['../payment/index']);
                    
                } else {
                    Yii::$app->session->setFlash('error','Something went wrong');
                    return $this->redirect(['../document-upload/index']);
                }
                      
            } else {
                Yii::$app->session->setFlash('error','Validation Error!');
                return $this->redirect(['../final-reviews/index']);
            }
            
            //$checkpoint = ApplicationFormStatusTbl::findOne(['CandidateID' => Yii::$app->user->identity->ID, 'ApplicationFormID' => 8]);
            //yii::$app->db->createCommand("exec FinalSubmitionfee :candidate_id")
            //    ->bindValue(':candidate_id', $ID)
            //    ->execute();
            //if (!$checkpoint) {
            //    /* Insert into Table Candidate */
            //    $candidate_id = Yii::$app->user->identity->ID;
            //    $form_id = 8;
            //    yii::$app->db->createCommand("exec FormSubmitConfirmation '$candidate_id','$form_id' ")->execute();  //finial submission  
            //}

            // userAct insert
            //$moduleName = 'Final-Submit';
            //$activityName = 'Form-Submit';
            //$data = array("moduleName" => $moduleName, "activityName" => $activityName);
            //Yii::$app->useract->useract($data);
            // end
            //Yii::$app->session->setFlash('success', 'Data saved successfully.');
            //return $this->redirect(['/payment/index']);
        }
        
        
        // echo "<pre>"; print_r($result); echo "<br><br><br><br>";
        if (isset($applicationStatus, $correctionStatus) && ($applicationStatus == 0) && ($correctionStatus == 1)) {

            // Personal Details
            // $personalCorrectionData = Yii::$app->db->createCommand("exec  getReviewDataPerCandidateCorrection :candidate_id")
            // ->bindValue(':candidate_id', $ID)
            // ->queryOne();

            // if(isset($personalCorrectionData) && !empty($personalCorrectionData)){
            //     foreach($personalCorrectionData as $key1 =>$value1){
            //         if(array_key_exists("$key1", $personalCorrectionData)){
            //             $result[$key1]= $personalCorrectionData[$key1];
            //         }
            //     }
            // }

    

        }

        // echo "<pre>"; print_r($result); die();

        if(isset($nextbuttonvisible) && $nextbuttonvisible == 0){
            Yii::$app->session->setFlash('error','Please upload your previous details');
            return $this->redirect(['../document-upload/index']);
        }

         $GenderCheck = Yii::$app->params['GenderCheck'];


        /* final submition*/
        return $this->render('reviewApplicationForm', [
      
            'model' => $result,
            'examcdata' => $examcdataresult,
            'examcdataresultCampus' => $examcdataresultCampus,
            'examParentOcup' => $ParentOcupdataresult,
            'parentQulificat' => $ParentQualifdataresult,
            'candidateUploadDocument' => $finalArray,
            'reviewexamCenter' => $ReviewexamCenter,
            'ReviewApplicationForm' => $ReviewApplicationForm,
            'canndidatePaymentStatus' => $canndidatePaymentStatus,
            'backLink' => 'document-upload/index',
            'buttonVisible' => $buttonVisible,
            'error_array' => $error_array,
            'GenderCheck' => $GenderCheck,
            //'data' => $data,
            //'requiredDoc' => $requireDoc[0],
            //'documentUpload' => $documentUpload

        ]);
    }
    
    /* 
     * create PDF File of REVIEW page
    */
    public function actionReviewpdf()
    {
        $ID = yii::$app->user->identity->ID;
        $result = \Yii::$app->db->createCommand("exec  getReviewData :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryOne();
        //echo"<pre>";print_r($result);die;
        /*Exam center */
        $examcdataresult = \Yii::$app->db->createCommand("exec  getReviewExamcenterData :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

        $examcdataresultCampus = \Yii::$app->db->createCommand("exec  getReviewExamcenterDataCampus :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();    

       // echo"<pre>";print_r($examcdataresultCampus);die;
           
        $ParentOcupdataresult = \Yii::$app->db->createCommand("exec  getReviewExamcenterparnOcupData :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

        $ParentQualifdataresult = \Yii::$app->db->createCommand("exec  getReviewExamcenterparnQualifData :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();
        
        /* File upload */
        $candidateUploadDocument = \Yii::$app->db->createCommand("exec  SpCandidateUplodedDoc :candidate_id")
            ->bindValue(':candidate_id', $ID)
            ->queryAll();

        // $GetTransactionData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table,:orderBy")
        //     ->bindValue(':select', 'CandidateID,InvoiceCode,TranscationID,ActualExamFee,PaidAmount,PaymentGatewayID,PaymentSubmitDate,PaymentSucessDate,PaymentStatus')
        //     ->bindValue(':input', "WHERE CandidateID='$ID' AND ResponseCode='00'")
        //     ->bindValue(':table', 'PaymentTranscationTbl')
        //     ->bindValue(':orderBy', 'order by PaymentSucessDate desc')
        //     ->queryOne();

        $GetTransactionData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table,:orderBy")
			->bindValue(':select', 'PaymentTranscationTbl.CandidateID,PaymentTranscationTbl.InvoiceCode,PaymentTranscationTbl.TranscationID,PaymentTranscationTbl.ActualExamFee,PaymentTranscationTbl.PaidAmount,PaymentTranscationTbl.PaymentGatewayID,PaymentTranscationTbl.PaymentSubmitDate,PaymentTranscationTbl.PaymentSucessDate,PaymentTranscationTbl.PaymentStatus,PaymentGatewayMst.GatewayName')
			->bindValue(':input', "left join PaymentGatewayMst on PaymentGatewayMst.ID = PaymentTranscationTbl.PaymentGatewayID WHERE CandidateID='$ID' AND (ResponseCode='00' OR ResponseCode='Success' OR ResponseCode='0300') ")
			->bindValue(':table', 'PaymentTranscationTbl')
			->bindValue(':orderBy', 'order by PaymentSucessDate desc')
			->queryOne();


        $twelveDocument = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'PassStatus12')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateID='.$ID)
            ->bindValue(':table', 'CandidateQualificationDetailsTblFinal')->queryOne();

        $fieldValidationRule = $this->getAllDocumentValidation();
        $finalArray = array();
        foreach ($fieldValidationRule as $data) {
            $documentName = strtolower(trim($data['DocumentName']));
            if (isset($data['IsRequired']) && $data['IsRequired'] == 1) {
                array_push($finalArray, $data);
            }
            if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['CastCategoryID']) && $data['IsRequired'] == 0 && ($result['CastCategoryID'] != 1) &&  preg_match("/category/i", strtolower($documentName))) {
                array_push($finalArray, $data);
            }
            if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['PhysicalDisability']) && $data['IsRequired'] == 0 && ($result['PhysicalDisability'] == 1) &&  preg_match("/pwd/i", strtolower($documentName))) {
                array_push($finalArray, $data);
            }

            if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['NeedScribe']) && $data['IsRequired'] == 0 && ($result['PhysicalDisability'] == 1 && $result['NeedScribe'] == 2) &&  preg_match("/scribe/i", strtolower($documentName))) {
                array_push($finalArray, $data);
            }

            if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['SubjecSpecializationMstID']) && $data['IsRequired'] == 0 && ($result['SubjecSpecializationMstID'] == 10074) &&  preg_match("/Artisan/i", strtolower($documentName))) {
                array_push($finalArray, $data);
            }
            
        }
        
        if (isset($finalArray) && isset($candidateUploadDocument) &&  !empty($finalArray) && !empty($candidateUploadDocument)) {
           $visiviltyCount = 0;
           foreach ($finalArray as $k1 => $v1) {
               foreach ($candidateUploadDocument as $k2 => $v2) {
                   if (isset($v1) && isset($v2['DocumentID']) && !empty($v1['ID']) && !empty($v2['DocumentID']) && $v1['ID'] == $v2['DocumentID']) {
                       $finalArray[$k1]['UploadDocument'] = $v2['UploadDocument'];
                       $visiviltyCount++;
                   }
               }
           }
        }
        $b = true;
        $content = $this->renderPartial('reviewpdf', [
            'model' => $result,
            'examcdata' => $examcdataresult,
            'examcdataresultCampus' => $examcdataresultCampus,
            'examParentOcup' => $ParentOcupdataresult,
            'parentQulificat' => $ParentQualifdataresult,
            'documentUpload' => $finalArray,
            'GetTransactionData'=>$GetTransactionData,
            'IsPwd'=>((Yii::$app->user->identity->PhysicalDisability == 1) || (Yii::$app->user->identity->PhysicalDisability == 2)) ? 'yes' : 'no',
        ]);

      //  echo $content; die;
        $mpdf = new mPDF();
        $mpdf->WriteHTML($content);
        $mpdf->showImageErrors = true;
        $mpdf->Output();
        exit;
    }
    
    public function actionFileDownload($FileName = null, $Status = 0)
    {
        if (isset(yii::$app->params['IsdocumentuploadAPI']) && !empty(yii::$app->params['IsdocumentuploadAPI'])) {
            if (isset($FileName) && !empty($FileName)) {
                if ($Status == 1) {
                    $fileName = $FileName;
                    $fileBasePath = (isset(yii::$app->params['IsdocumentuploadAPI']) && !empty(yii::$app->params['IsdocumentuploadAPI'])) ? yii::$app->params['documentPathAPI'].'/'.Yii::$app->params['containerName'].'/' : Yii::getAlias('@frontendweb') . '/uploads/';
                    $originalFilePath = $fileBasePath . $fileName;
                } else {
                    $fileName = $FileName;
                    $fileName = base64_decode($fileName);
                    $fileBasePath = (isset(yii::$app->params['IsdocumentuploadAPI']) && !empty(yii::$app->params['IsdocumentuploadAPI'])) ? yii::$app->params['documentPathAPI'].'/'.Yii::$app->params['containerName'].'/' : Yii::getAlias('@frontendweb') . '/uploads/';
                    //$originalFilePath = $fileBasePath . $fileName;
                    $originalFilePath = $fileName;
                }
                 $originalFilePath= $originalFilePath;
              
                if (isset($fileName) && !empty(@fopen("$originalFilePath", 'r'))) {
                    $actuarrayFileName = 'NIFT-' . time() . '.pdf';
                    // Force download
                    header("Content-type: application/x-file-to-save");
                    header("Content-Disposition: attachment; filename=" . basename($actuarrayFileName));
                    ob_end_clean();
                    readfile($originalFilePath);
                    exit;
                } else {
                    echo "File Not Exist";
                    die;
                }
            }

        }else{
        if (isset($FileName) && !empty($FileName)) {
            if ($Status == 1) {
                $fileName = $FileName;
                $fileBasePath = Yii::getAlias('@frontendweb') . '/uploads/';
                $originalFilePath = $fileBasePath . $fileName;
            } else {
                $fileName = $FileName;
                    $fileName = base64_decode($fileName);
                $fileBasePath = Yii::getAlias('@frontendweb') . '/uploads/';
                $originalFilePath = $fileBasePath . $fileName;
            }
            //echo $originalFilePath;die;
            if (isset($fileName) && file_exists($originalFilePath)) {
                 $actuarrayFileName = 'NIFT-' . time() . '.pdf';

                    $actuarrayFileName = 'NIFT-' . time() . '.pdf';
                    // Force download
                    header("Content-type: application/x-file-to-save");
                    header("Content-Disposition: attachment; filename=" . basename($actuarrayFileName));
                    ob_end_clean();
                    readfile($originalFilePath);
                    exit;
            } else {
                echo "File Not Exist";
                die;
            }
        }
    }
}

    public function actionDownloadForm()
    {
		
        if (isset(Yii::$app->user->identity->ApplicationFinalSubmit) && !empty(Yii::$app->user->identity->ApplicationFinalSubmit) && Yii::$app->user->identity->ApplicationFinalSubmit == 1) {
//            $DB = Yii::$app->session->get('NewDB');
//            if (empty($DB)) {
//                return $this->redirect(['/site/login']);
//            }
            $candidateID = yii::$app->user->identity->ID;
            $result = \Yii::$app->db->createCommand("exec  getReviewData :candidate_id")
                ->bindValue(':candidate_id', $candidateID)
                ->queryOne();

            $examcdataresult = \Yii::$app->db->createCommand("exec  getReviewExamcenterData :candidate_id")
                ->bindValue(':candidate_id', $candidateID)
                ->queryAll();

            $examcdataresultCampus = \Yii::$app->db->createCommand("exec  getReviewExamcenterDataCampus :candidate_id")
                ->bindValue(':candidate_id', $candidateID)
                ->queryAll();   


            $ParentOcupdataresult = \Yii::$app->db->createCommand("exec  getReviewExamcenterparnOcupData :candidate_id")
                ->bindValue(':candidate_id', $candidateID)
                ->queryAll();
            $ParentQualifdataresult = \Yii::$app->db->createCommand("exec  getReviewExamcenterparnQualifData :candidate_id")
                ->bindValue(':candidate_id', $candidateID)
                ->queryAll();
             /* File upload */
            $candidateUploadDocument = \Yii::$app->db->createCommand("exec  SpCandidateUplodedDoc :candidate_id")
                ->bindValue(':candidate_id', $candidateID)
                ->queryAll();

            // $GetTransactionData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table,:orderBy")
            //     ->bindValue(':select', 'CandidateID,InvoiceCode,TranscationID,ActualExamFee,PaidAmount,PaymentGatewayID,PaymentSubmitDate,PaymentSucessDate,PaymentStatus')
            //     ->bindValue(':input', "WHERE CandidateID='$candidateID' AND (ResponseCode='00' OR ResponseCode='Success')")
            //     ->bindValue(':table', 'PaymentTranscationTbl')
            //     ->bindValue(':orderBy', 'order by PaymentSucessDate desc')
            //     ->queryOne();

            $GetTransactionData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table,:orderBy")
                ->bindValue(':select', 'PaymentTranscationTbl.CandidateID,PaymentTranscationTbl.InvoiceCode,PaymentTranscationTbl.TranscationID,PaymentTranscationTbl.ActualExamFee,PaymentTranscationTbl.PaidAmount,PaymentTranscationTbl.PaymentGatewayID,PaymentTranscationTbl.PaymentSubmitDate,PaymentTranscationTbl.PaymentSucessDate,PaymentTranscationTbl.PaymentStatus,PaymentGatewayMst.GatewayName')
                ->bindValue(':input', "left join PaymentGatewayMst on PaymentGatewayMst.ID = PaymentTranscationTbl.PaymentGatewayID WHERE CandidateID='$candidateID' AND (ResponseCode='00' OR ResponseCode='Success') ")
                ->bindValue(':table', 'PaymentTranscationTbl')
                ->bindValue(':orderBy', 'order by PaymentSucessDate desc')
                ->queryOne();
            
            $twelveDocument = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                ->bindValue(':select', 'PassStatus12')
                ->bindValue(':input', 'WHERE IsActive=1 and CandidateID='.$candidateID)
                ->bindValue(':table', 'CandidateQualificationDetailsTblFinal')->queryOne();

            $fieldValidationRule = $this->getAllDocumentValidation();
            $finalArray = array();
            foreach ($fieldValidationRule as $data) {
                $documentName = strtolower(trim($data['DocumentName']));
                if (isset($data['IsRequired']) && $data['IsRequired'] == 1) {
                    array_push($finalArray, $data);
                }
                if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['CastCategoryID']) && $data['IsRequired'] == 0 && ($result['CastCategoryID'] != 1) &&  preg_match("/category/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                }
                if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['PhysicalDisability']) && $data['IsRequired'] == 0 && ($result['PhysicalDisability'] == 1) &&  preg_match("/pwd/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                }
                if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['NeedScribe']) && $data['IsRequired'] == 0 && ($result['PhysicalDisability'] == 1 && $result['NeedScribe'] == 2) &&  preg_match("/scribe/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                }
                if (isset($data['IsRequired']) && isset($data['DocumentName']) && isset($result['SubjecSpecializationMstID']) && $data['IsRequired'] == 0 && ($result['SubjecSpecializationMstID'] == 10074) &&  preg_match("/Artisan/i", strtolower($documentName))) {
                    array_push($finalArray, $data);
                }

            }
            if (isset($finalArray) && isset($candidateUploadDocument) &&  !empty($finalArray) && !empty($candidateUploadDocument)) {
                $visiviltyCount = 0;
                foreach ($finalArray as $k1 => $v1) {
                    foreach ($candidateUploadDocument as $k2 => $v2) {
                        if (isset($v1) && isset($v2['DocumentID']) && !empty($v1['ID']) && !empty($v2['DocumentID']) && $v1['ID'] == $v2['DocumentID']) {
                            $finalArray[$k1]['UploadDocument'] = $v2['UploadDocument'];
                            $visiviltyCount++;
                        }
                    }
                }
            }
            array_multisort( array_column($examcdataresult, "ExamCenterPriorty"), SORT_ASC, $examcdataresult );	
            $content = $this->renderPartial('reviewpdf', [
                    'model' => $result,
                    'examcdata' => $examcdataresult,
                    'examParentOcup' => $ParentOcupdataresult,
                    'parentQulificat' => $ParentQualifdataresult,
                    'documentUpload' => $finalArray,
                    'GetTransactionData'=>$GetTransactionData,
                    'examcdataresultCampus' => $examcdataresultCampus,
                    'IsPwd'=>((Yii::$app->user->identity->PhysicalDisability == 1) || (Yii::$app->user->identity->PhysicalDisability == 2)) ? 'yes' : 'no',
            ]);

            $fileName = yii::$app->user->identity->ApplicationNumber . time() . '.pdf';
            $mpdf = new mPDF();
            $mpdf->WriteHTML($content);
            $mpdf->showImageErrors = true;
            $mpdf->Output($fileName, 'D');
        } else {
            return $this->redirect(['../site/login']);
        }
    }

    public function getAllDocumentValidation()
    {
//        $DB = Yii::$app->session->get('NewDB');
//        if (empty($DB)) {
//            return $this->redirect(['/site/login']);
//        }
        $validationArray = array();
        $allDocumentArray = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
        ->bindValue(':select', '*')
        ->bindValue(':input', "WHERE IsActive=1 order by ID asc")
        ->bindValue(':table', 'DocumentMst')->queryAll();
        if (isset($allDocumentArray) && !empty($allDocumentArray)) {
            return $allDocumentArray;
        }
        return $validationArray;
    }

    public function checkFormStaus($CandidateID,$ApplicationID){
//        $DB = Yii::$app->session->get('NewDB');
//        if (empty($DB)) {
//            return $this->redirect(['/site/login']);
//        }
        $ApplicationFormStatusTbl = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                        ->bindValue(':select', 'ID,CandidateID,ApplicationFormID,CompletedDate,IsComplete,IsActive')
                        ->bindValue(':input', 'WHERE ApplicationFormID='.$ApplicationID.'AND CandidateID='.$CandidateID)
                        ->bindValue(':table', 'ApplicationFormStatusTbl')->queryOne();
        return $ApplicationFormStatusTbl;

    }
    
}