<?php

namespace app\modules\application\controllers;

use app\modules\application\models\PersonalDetails;
use yii\helpers\ArrayHelper;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii;
use yii\filters\AccessControl;
/**
 * PersonalController implements the CRUD actions for AadharDetails model.
 */
class PersonalController extends Controller
{
    /**
     * @inheritDoc
     */
    public function behaviors()
    {
        return array_merge(
            parent::behaviors(),
            [
                'access' => [
                    'class' => AccessControl::class,
                    'rules' => [
                        [
                            'actions' => [
                                'logout', 'index', 'captcha'
                            ],
                            'allow' => true,
                            'roles' => ['@'],
                        ],
                    ],
                ],
                'verbs' => [
                    'class' => VerbFilter::className(),
                    'actions' => [
                        'delete' => ['POST'],
                    ],
                ],
            ]
        );
    }

    /**
     * {@inheritdoc}
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => \yii\web\ErrorAction::class,
            ],
            'captcha' => [
                'class'=> 'common\captcha\CaptchaAction',
                'fixedVerifyCode' => YII_ENV_TEST ? 'testme' : null,
            ],
        ];
    }

        
    public function actionIndex()
    {
        // return $this->redirect(['../dashboard/index']);
        // die();

         //check point 
        //  if (!yii::$app->ApplicationOpen->Openwindow()) {
        //     return $this->redirect(['/site/login']);
        // }
      //  $applicationWindowStart = Yii::$app->ApplicationOpen->Openwindow(); // Check if Application Window Start, 1 = Active, 0= InActive
       // $correctionWindowStart = Yii::$app->CorrectionWindow->Openwindow(); // Check if Correction Window Start, 1 = Active, 0= InActive

       $applicationStatus = Yii::$app->ApplicationOpen->Openwindow();
       $correctionStatus = Yii::$app->CorrectionWindow->Openwindow();

       $isCandidateAllowCorrection = Yii::$app->CheckCorrectionAndApplicationStatus->CheckStatus($applicationStatus, $correctionStatus);

       if (isset($isCandidateAllowCorrection, $isCandidateAllowCorrection['status'], $isCandidateAllowCorrection['msg']) && !empty($isCandidateAllowCorrection) && ($isCandidateAllowCorrection['status'] == 0) && !empty($isCandidateAllowCorrection['msg'])) {
     
           Yii::$app->session->setFlash('error', $isCandidateAllowCorrection['msg']);
           return $this->redirect(['../dashboard/index']);
       }

    //    die('stop');
        // if (Yii::$app->user->identity->ApplicationFinalSubmit == 1 || Yii::$app->user->identity->PaymentStatus == 1) {
        //     return $this->redirect(['../dashboard/index']);
        // }

        
        /* check Form Status here And User is exsit*/
        if (isset(yii::$app->user->identity->ID) && !empty(yii::$app->user->identity->ID)) {
            $CandidateID = Yii::$app->user->identity->ID;
        } else {
            Yii::$app->session->setFlash('error', 'Unauthorised access.');
            return $this->redirect('../site/login');
        }

        $getFormStatusCheck = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                                                ->bindValue(':select', 'ID')
                                                ->bindValue(':input', 'WHERE CandidateID=' . $CandidateID . ' and ApplicationFormID=1')
                                                ->bindValue(':table', 'ApplicationFormStatusTbl')
                                                ->queryOne();
        if (empty($getFormStatusCheck)) {
            Yii::$app->session->setFlash('error', 'Please fill your contact details');
            return $this->redirect(['../contact/index']);
        }

        $examDate = strtotime(date('Y-m-d', strtotime(yii::$app->params['examStartDate'])) . "-" . yii::$app->params['ageMin'] . "year");
        $MinYear = date('Y', ($examDate));
        $examDate = strtotime(date('Y-m-d', strtotime(yii::$app->params['examStartDate'])) . "-" . yii::$app->params['ageMax'] . " year");
        $MaxYear = date('Y', ($examDate));
        //day name
        for ($i = 1; $i <= 31; $i++) {
            $DobDate[str_pad($i, 2, '0', STR_PAD_LEFT)] = str_pad($i, 2, '0', STR_PAD_LEFT);
        }
        //$DobYear = [];
        //month name
        for ($m = 1; $m <= 12; ++$m) {
            $DobMonth[str_pad($m, 2, '0', STR_PAD_LEFT)] = date('F', mktime(0, 0, 0, $m, 1));
        }
        //year name
        for ($year = $MaxYear; $year <= $MinYear; $year++) {
            $DobYear[$year] = $year;
        }

        $ID = yii::$app->user->identity->ID;
        $personalDetail = $this->findPersonDetailSaveModel($ID);       
        if(isset($personalDetail) && !empty($personalDetail)){
            $personalDetail=$personalDetail;
        } else {
             $personalDetail = new PersonalDetails();    
        }


        // $PasSubjData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
        //                         ->bindValue(':select', 'SubjectID')
        //                         ->bindValue(':input', 'WHERE CandidateID='.$ID)
        //                         ->bindValue(':table', 'CandidatePassedSubjectTbl')
        //                         ->queryOne();
        // $PasSubj = [];
        // if(isset($PasSubjData)&& !empty($PasSubjData)){
        //     $PasSubj = $PasSubjData;
        // }


        if ($this->request->isPost) {
            if ($personalDetail->load($this->request->post()) && $personalDetail->validate()) {
                $postData = Yii::$app->request->post();  
                $data = [];
                foreach ($postData['PersonalDetails'] as $key => $value) {       
                    $data['PersonalDetails']["$key"] = Yii::$app->SanatizeInput->getInput($value);
                }
                $userData =  $data['PersonalDetails'];                            
                $Day = $data['PersonalDetails']['Day'];
                $Month = $data['PersonalDetails']['Month'];
                $Year = $data['PersonalDetails']['Year'];

                $userData['DOB'] = $Year . '-' . $Month . '-' . $Day;


                if(isset($data['PersonalDetails']['CastCategoryID']) && $data['PersonalDetails']['CastCategoryID'] == 1){
                    $userData['CategoryCertificateDate'] = null;
                    $userData['CertificateAuthorityName'] = null;
                    $userData['CatCertificateNumber'] = null;
                    $userData['SubCategory'] = null;
                }else{
                    $CategoryCertificateDay = $data['PersonalDetails']['CategoryCertificateDay'];
                    $CategoryCertificateMonth = $data['PersonalDetails']['CategoryCertificateMonth'];
                    $CategoryCertificateYear = $data['PersonalDetails']['CategoryCertificateYear'];
                    //$userData['DOB'] = $Day . '-' . $Month . '-' . $Year;
                    $userData['CategoryCertificateDate'] = $CategoryCertificateYear . '-' . $CategoryCertificateMonth . '-' . $CategoryCertificateDay;

                    $CategoryCertificateDateCorrection = trim($userData['CategoryCertificateDate']);
                    if(strtotime($CategoryCertificateDateCorrection) > strtotime('2025-02-28')){
                        Yii::$app->session->setFlash('error', 'Certificate issue date must not be later than 28-02-2025');
                        return $this->redirect(['../personal/index']);
                    }   

                }


                if($postData['PersonalDetails']['IsNameChangeStatus']=='CandidateName'){
                    $userData['CandidateName'] = $postData['PersonalDetails']['CandidateName'];
                    $userData['FatherName'] = Yii::$app->user->identity->FatherName;
                    $userData['MotherName'] = Yii::$app->user->identity->MotherName;
                    
                }elseif($postData['PersonalDetails']['IsNameChangeStatus']=='FatherName'){
                    $userData['CandidateName'] =  Yii::$app->user->identity->CandidateName;
                    $userData['FatherName'] = $postData['PersonalDetails']['FatherName'];
                    $userData['MotherName'] = Yii::$app->user->identity->MotherName;
                }elseif($postData['PersonalDetails']['IsNameChangeStatus']=='MotherName'){
                    $userData['CandidateName'] =  Yii::$app->user->identity->CandidateName;
                    $userData['FatherName'] = Yii::$app->user->identity->FatherName;
                    $userData['MotherName'] = $postData['PersonalDetails']['MotherName'];
                }

                $CandidateIP =   'Unknown';
                if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
                    $CandidateIP = $_SERVER['HTTP_CLIENT_IP'];
                } else if (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
                    $CandidateIP = $_SERVER['HTTP_X_FORWARDED_FOR'];
                } else {
                    $CandidateIP = $_SERVER['REMOTE_ADDR'];
                }

                $userData['CandidateID'] = $ID;
                $userData['CandidateIP'] = $CandidateIP;
                $userData['ApplicationFormID'] = 2;
                $userData['IdentityID'] = $data['PersonalDetails']['IdentityID'];
                $userData['CreateDate'] = date('Y-m-d H:i:s');
                $userData['IdentityNumber'] = trim($data['PersonalDetails']['IdentityNumber']);
                
                if(isset($userData['PhysicalDisability']) && ($userData['PhysicalDisability'] != 3 )){
                    
                    $DayScribe = $data['PersonalDetails']['DayScribe'];
                    $MonthScribe = $data['PersonalDetails']['MonthScribe'];
                    $YearScribe = $data['PersonalDetails']['YearScribe'];
                    //$userData['DOB'] = $Day . '-' . $Month . '-' . $Year;
                    if(isset($data['PersonalDetails']['NeedScribe']) && $data['PersonalDetails']['NeedScribe']==2 ){
                        $userData['dateOfIssesScribe'] = $YearScribe . '-' . $MonthScribe . '-' . $DayScribe;
                    }else{
                        $userData['dateOfIssesScribe'] = null;
                    }
                    
                    $userData['adharNumberScribe'] = $data['PersonalDetails']['adharNumberScribe'];
                    $userData['qualificationScribe'] = $data['PersonalDetails']['qualificationScribe'];
                    $userData['scribeName'] = $data['PersonalDetails']['scribeName'];
                }
                
                if(isset($userData['PhysicalDisability']) && $userData['PhysicalDisability'] == 1 ){
                    $userData['DisabilyType'] = $data['PersonalDetails']['DisabilyType'];
                }else if(isset($userData['PhysicalDisability']) && $userData['PhysicalDisability'] == 2 ){
                    $userData['DisabilyType'] = $data['PersonalDetails']['DisabilyTypeTwo'];
                }else{
                    $userData['DisabilyType'] = null; 
                }
                // Check validation  for OBC-NCL AS PER CENTRAL LIST == 5 
                if(isset($userData['CastCategoryID']) && $userData['CastCategoryID'] !=5){
                    $userData['SubCategory'] = null;
                }

                // echo "<pre>";
                // print_r($userData);
                // die;
                // Check validation  for PwD candidate
                if(isset($userData['PhysicalDisability']) && $userData['PhysicalDisability'] == 3){
                    $userData['IsUDIDNumber'] = null; 
                    $userData['DisabilyType'] = null; 
                    $userData['DisabilityPercentage'] = null; 
                    $userData['NeedScribe'] = null; 
                    $userData['UDIDNumber'] = null;

                    $userData['dateOfIssesScribe'] = null;
                    $userData['adharNumberScribe'] = null;
                    $userData['qualificationScribe'] = null;
                    $userData['scribeName'] = null;

                }
                
                // Check validation  for PwD candidate
                if(isset($userData['PhysicalDisability'],$userData['IsUDIDNumber']) && ($userData['PhysicalDisability']==1 || $userData['PhysicalDisability']==2) && ($userData['IsUDIDNumber']==0)){
                    $userData['UDIDNumber'] = null;   
                }

                // Check validation  for candidate is  KashmiriMigrant
                if(isset($userData['KashmiriMigrant'],$userData['DomicileCategory']) && ($userData['KashmiriMigrant'] == 1) && ($userData['DomicileCategory'] == 1) ){
                    $userData['DomicileState'] = null;
                }

                // $castCategoryData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                //                         ->bindValue(':select', 'ID,CategoryCode,CategoryName')
                //                         ->bindValue(':input', 'WHERE IsActive=1 AND ID='.$data['PersonalDetails']['CastCategoryID'])
                //                         ->bindValue(':table', 'CasteCategoryMst')->queryOne();

                // echo "<pre>"; print_r($userData); die();

                // $json['user_data'] = $userData;   
                
                $jsonParams = json_encode($userData); 

                // echo $jsonParams; die();

                if (isset($applicationStatus, $correctionStatus) && ($applicationStatus == 1) && ($correctionStatus == 0)) {
                    $sp = '{{%UpdateCandidatePersonal}}';
                    $response = Yii::$app->db->createCommand("exec $sp @json = :json")
                                            ->bindValue(':json', $jsonParams)
                                            ->execute();   
                                        //    echo  $response; die;                                  
                    if (isset($response) && $response == 0) {
                         //Activity Log START
                         $moduleName = 'Personal Details';
                         $nextURL='exam-center/index';
                         $NextActivityURL = isset($nextURL) ? str_replace("../", "", $nextURL) : 'NA';
                         $activityName = $moduleName . ' '.Yii::$app->params['ActivityDescriptionForControllers']. ' '. $NextActivityURL;
                         $data = array(
                             "applicationWindowStart" => $applicationStatus, "correctionWindowStart" => $correctionStatus,
                             "moduleName" => $moduleName,
                             "activityName" => $activityName
                         );
                         Yii::$app->useract->useract($data);
                         //Activity Log END
                         
                         Yii::$app->session->setFlash('success', 'Personal details saved successfully.');
                         return $this->redirect(['../exam-center/index']);
    
    
                    }else{
                        Yii::$app->session->setFlash('error', "Something went wrong.");
                        return $this->redirect(['../personal/index']);
                    }

                }else if (isset($applicationStatus, $correctionStatus) && ($applicationStatus == 0) && ($correctionStatus == 1)) {

                    $ApplicationNumber = Yii::$app->user->identity->ApplicationNumber;
                    $CandidateIP = Yii::$app->masterdata->getCandidateIP();
                    $personalData = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                    ->bindValue(':select', 'CandidateName,FatherName,MotherName')
                    ->bindValue(':input', "WHERE ID=$CandidateID and ApplicationNumber='" . $ApplicationNumber . "' and IsActive=1 ")
                    ->bindValue(':table', 'CandidateTbl')
                    ->queryOne();

                $IsNameChangeStatus = $userData['IsNameChangeStatus'] ?? '';
                if ($IsNameChangeStatus == 'CandidateName') {
                    $userData['CandidateName'] = $userData['CandidateName'];
                    $userData['FatherName'] = $personalData['FatherName'];
                    $userData['MotherName'] = $personalData['MotherName'];
                } else if ($IsNameChangeStatus == 'FatherName') {
                    $userData['FatherName'] = $userData['FatherName'];
                    $userData['MotherName'] = $personalData['MotherName'];
                    $userData['CandidateName'] = $personalData['CandidateName'];
                } else if ($IsNameChangeStatus == 'MotherName') {
                    $userData['MotherName'] = $userData['MotherName'];
                    $userData['FatherName'] = $personalData['FatherName'];
                    $userData['CandidateName'] = $personalData['CandidateName'];
                } else {
                    $userData['CandidateName'] = $personalData['CandidateName'];
                    $userData['FatherName'] = $personalData['FatherName'];
                    $userData['MotherName'] = $personalData['MotherName'];
                }
                
                    $sp3 = '{{%saveUpdateCorrectionWindowData}}';
                    $responseCorrection = Yii::$app->db->createCommand("exec $sp3 :candidateID,:ApplicationNumber,:jsonData,:fieldname,:tablename,:currentTime,:candidateIP")
                        ->bindValue(':candidateID', $CandidateID)
                        ->bindValue(':ApplicationNumber', $ApplicationNumber)
                        ->bindValue(':jsonData', $jsonParams)
                        ->bindValue(':fieldname', 'PersonalDetails')
                        ->bindValue(':tablename', 'CandidateCorrectionDataTbl')
                        ->bindValue(':currentTime', date('Y-m-d H:i:s'))
                        ->bindValue(':candidateIP', $CandidateIP)
                        // ->bindValue(':candidateIP', Yii::$app->masterdata->getUserIP())
                        ->execute();
                        if (isset($personalDetail->IdentityNumber) && !empty($personalDetail->IdentityNumber)) {
                            $personalDetail->IdentityNumber = $personalDetail->IdentityNumber;
                        }
                        // echo "<pre>";print_r($responseCorrection);die;
                    if (isset($responseCorrection) && $responseCorrection == 0) {

                        $IsNameChangeStatus = isset($userData['IsNameChangeStatus']) ? $userData['IsNameChangeStatus'] : '';
                        if (isset($IsNameChangeStatus) && $IsNameChangeStatus != '') {
                            Yii::$app->db->createCommand("exec updateCommonDataSP :updatefields, :where, :table")
                                ->bindValue(':updatefields', "IsNameChangeStatus='" . $IsNameChangeStatus . "'")
                                ->bindValue(':where', "WHERE CandidateID=$CandidateID AND ApplicationNumber='$ApplicationNumber'")
                                ->bindValue(':table', 'CandidateCorrectionDataTbl')
                                ->execute();
                        }
                           //Activity Log START
                           $moduleName = 'Personal-Details-Correction';
                           $nextURL='exam-center/index';
                           $NextActivityURL = isset($nextURL) ? str_replace("../", "", $nextURL) : 'NA';
                           $activityName = $moduleName . ' '.Yii::$app->params['ActivityDescriptionForControllers']. ' '. $NextActivityURL;
                           $data = array(
                               "applicationWindowStart" => $applicationStatus, "correctionWindowStart" => $correctionStatus,
                               "moduleName" => $moduleName,
                               "activityName" => $activityName
                           );
                           Yii::$app->useract->useract($data);
                           //Activity Log END

                        Yii::$app->session->setFlash('success', Yii::$app->params['CandidateFormSaveMsg']);
                        return $this->redirect(['../exam-center/index']);
                    } else {
                        Yii::$app->session->setFlash('error', 'Something went wrong.');
                        return $this->redirect(['../personal/index']);
                    }
                }

            }else {
                $personalDetail->loadDefaultValues();
            }
        } 

        if(isset($personalDetail->IdentityNumber) && !empty($personalDetail->IdentityNumber)){
            $personalDetail->IdentityNumber = $personalDetail->IdentityNumber;
        }

        // die('stop');

        if (isset($applicationStatus, $correctionStatus) && ($applicationStatus == 0) && ($correctionStatus == 1)) {

            $PersonalDetailsDataArray = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
            ->bindValue(':select', 'PersonalDetails')
            ->bindValue(':input', 'WHERE IsActive=1 and CandidateID=' . $CandidateID)
                ->bindValue(':table', 'CandidateCorrectionDataTbl')
                ->queryOne();

            if (isset($PersonalDetailsDataArray, $PersonalDetailsDataArray['PersonalDetails']) && !empty($PersonalDetailsDataArray) && !empty($PersonalDetailsDataArray['PersonalDetails'])) {
                $PersonalDetailsData = json_decode($PersonalDetailsDataArray['PersonalDetails'], true);

                if(isset($PersonalDetailsData) && !empty($PersonalDetailsData)){
                    foreach ($PersonalDetailsData as $key => $values) {

                        $unsetArray = array('IsActive', 'CreateDate', 'ApplicationFormID', 'CandidateID', 'CandidateMobile', 'CandidateEmail', 'verifyCode');
    
                        if (isset($key, $unsetArray) && is_array($unsetArray) && in_array($key, $unsetArray)) {
                            unset($PersonalDetailsData["$key"]);
                            continue;
                        }
    
                        $personalDetail->{$key} = $values;
                    }
                }

               
                // echo '<pre>';print_r($PersonalDetailsData); die;

            }
        }

        // die('test');


        $Country = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table,:orderBy")
        ->bindValue(':select', 'ID,CountryName,Nationality')
        ->bindValue(':input', "WHERE IsActive=1 and CountryCode='IN'")
        ->bindValue(':table', 'CountryMst')
        ->bindValue(':orderBy', 'order by  CountryName ASC')
        ->queryAll();

        $State = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
        ->bindValue(':select', 'ID,UPPER(StateName) as StateName')
        ->bindValue(':input', 'WHERE IsActive=1')
        ->bindValue(':table', 'StateMst')
        ->bindValue(':orderBy', 'order By StateName asc')
        ->queryAll();
        
        $CategoryArray = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table,:orderBy")
        ->bindValue(':select', 'ID,CategoryName')
        ->bindValue(':input', "WHERE IsActive=1 ")
        ->bindValue(':table', 'CasteCategoryMst')
        ->bindValue(':orderBy', 'order by  Sequence ASC')
        ->queryAll();
        $Identity_data = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table,:orderBy")
        ->bindValue(':select', 'ID,IdentityName')
        ->bindValue(':input', "WHERE IsActive=1")
        ->bindValue(':table', 'IdentityMst')
        ->bindValue(':orderBy', 'order by IdentityName ASC')
        ->queryAll();
        $disability_data = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table,:orderBy")
        ->bindValue(':select', 'ID,Name')
        ->bindValue(':input', "WHERE IsActive=1")
        ->bindValue(':table', 'DisabilyTypeMst')
        ->bindValue(':orderBy', 'order by Name ASC')
        ->queryAll();
        $Gender = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table, :orderBy")
        ->bindValue(':select', 'ID,Gender')
        ->bindValue(':input', 'WHERE IsActive=1')
        ->bindValue(':table', 'GenderMst')
        ->bindValue(':orderBy', 'order By ID asc')
        ->queryAll();
        $Gender_data = (!empty($Gender)) ? ArrayHelper::map($Gender, 'ID', 'Gender') : [];
        $Country_data = (!empty($Country)) ? ArrayHelper::map($Country, 'ID', 'Nationality') : [];
        // $DomicileState = (!empty($State)) ? ArrayHelper::map($State, 'ID', 'StateName') : [];
        $Category_data = (!empty($CategoryArray)) ? ArrayHelper::map($CategoryArray, 'ID', 'CategoryName') : [];
        $IdentityIDs = (!empty($Identity_data)) ? ArrayHelper::map($Identity_data, 'ID', 'IdentityName') : [];
        $typeofdisability = (!empty($disability_data)) ? ArrayHelper::map($disability_data, 'ID', 'Name') : [];
       
       // echo"<pre>";print_r($personalDetail['DisabilyTypeTwo']);die;

        $DomicileState = ArrayHelper::map($State, 'ID', 'StateName');
        $DomicileState[0] = 'OUT SIDE INDIA';
        if (($key = array_search('OTHER', $DomicileState)) !== false) {
            unset($DomicileState[$key]);
        }

        $CateMaxYear = date("Y", strtotime($personalDetail['DOB']));
        $CateMinYear = date("Y", strtotime(date('Y')));

        for ($Cateyear = $CateMaxYear; $Cateyear <= $CateMinYear; $Cateyear++) {
            $CertificateYear[$Cateyear] = $Cateyear;
        }

        $year = date("Y", strtotime($personalDetail['CategoryCertificateDate']));
        if(isset($personalDetail->PhysicalDisability) && ($personalDetail->PhysicalDisability == 1)){
            $personalDetail->DisabilyType = $personalDetail->DisabilyType;
        }elseif (isset($personalDetail->PhysicalDisability) && ($personalDetail->PhysicalDisability == 2)){
            $personalDetail->DisabilyTypeTwo = $personalDetail->DisabilyType;
        } else {
            $personalDetail->DisabilyType = null;
            $personalDetail->DisabilyTypeTwo = null;
        }
        // DisabilyType
        
        // DisabilyType
        // DisabilyTypeTwo

        return $this->render('index', [
            'model' => $personalDetail,
            // 'PasSubj' => $PasSubj,
            'DobDate' => $DobDate,
            'DobMonth' => $DobMonth,
            'DobYear' => $DobYear,
            'CertificateYear' => $CertificateYear,
            'Country_data' => $Country_data,
            'DomicileState' => $DomicileState,
            'CategoryArray' => $Category_data,
            'typeofdisability' => $typeofdisability,
            'IdentityIDs' => $IdentityIDs,
            'Gender_data' => $Gender_data,
            'backLink' => 'contact/index',
            'correctionStatus' => $correctionStatus
        ]);
    }


    protected function findPersonDetailSaveModel($ID)
    {
        if (($model = PersonalDetails::findOne(['ID' => $ID])) !== null) {
            return $model;
        }
        throw new NotFoundHttpException('The requested page does not exist.');
    }

    public function actionCastCategoryCodeById($id){
        // $DB = Yii::$app->session->get('NewDB');
        // if (empty($DB)) {
        //     return $this->redirect(['/site/login']);
        // }
        if($id == null){
            echo  json_encode(['CategoryCode'=>null]);
            exit;
        }
        $cast_category_id = $id;
        $onlyDigitAllow = preg_match('/^[0-9,_]+$/', $id);
        if(!$onlyDigitAllow){
            echo  json_encode(['CategoryCode' => null]);
            exit;
        }
        $castCategory = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                                        ->bindValue(':select', 'ID,CategoryCode,CategoryName')
                                        ->bindValue(':input', 'WHERE IsActive=1 AND ID='.$cast_category_id)
                                        ->bindValue(':table', 'CasteCategoryMst')->queryOne();
        if(isset($castCategory) && !empty($castCategory)){
            if($castCategory['CategoryCode'] == 'OBCNCL'){
                echo  json_encode(['CategoryCode'=>'OBCNCL']);
                exit;
            }
            if($castCategory['CategoryCode'] == 'SC'){
                echo json_encode(['CategoryCode'=>'SC']);
                exit;
            }
            echo  json_encode(['CategoryCode'=>null]);
            exit;
        } else {
            echo  json_encode(['CategoryCode'=>null]);
            exit;
        }
        
    }

 public function actionUpdatePersonalDetails()
    {

        $ApplicationNumber = yii::$app->user->identity->ApplicationNumber;
        if (isset($ApplicationNumber, $_POST['getSelectVal']) && !empty($ApplicationNumber) && !empty($_POST['getSelectVal'])) {
            $key = $_POST['getSelectVal'];
            $candidateData = Yii::$app->db->CreateCommand("exec getCommonDataSp :select, :input, :table")
                ->bindValue(':select', 'CandidateName,FatherName,MotherName')
                ->bindValue(":input", "WHERE IsActive = 1 And ApplicationNumber = '$ApplicationNumber'")
                ->bindValue(":table", "CandidateTbl")->queryOne();
            // echo "<pre>"; print_r($CandidateData); die();
            $responseArr = [];
            if (isset($candidateData) && !empty($candidateData)) {
                $responseArr = array('CandidateName' => $candidateData['CandidateName'], 'FatherName' => $candidateData['FatherName'], 'MotherName' => $candidateData['MotherName']);
                // unset($responseArr[$key]); 
                $responseArr[$key] = "";
                //                if (array_key_exists("$key", $responseArr)) {
                //                    $responseArr[$key] = '';
                //                }
                return json_encode($responseArr);
            }
        }
    }


}
