<?php

namespace app\modules\application\models;

use Yii;
use app\modules\application\models\PersonalDetails;

/**
 * This is the model class for table "CandidateQualificationDetailsTbl".
 *
 * @property int $ID
 * @property int|null $CandidateID
 * @property int|null $CourseID
 * @property int|null $PassStatus
 * @property int|null $YearOfPassing
 * @property int|null $FinalResultAwating
 * @property int|null $QualifyingExamPlaceID
 * @property int|null $QualificationExamStateID
 * @property int|null $UniversityBoardID
 * @property int|null $ResultMode
 * @property float|null $MarksObtained
 * @property int|null $MPhilOptions
 * @property int|null $PhdOptions
 * @property string|null $ReasearchExServicemanDetailsSpecilization
 * @property string|null $ReasearchExServicemanPGExperience
 * @property string|null $ReasearchExServiceman
 * @property string|null $CreateDate
 * @property int|null $IsActive
 */
class CandidateQualificationDetailsTbl extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public $clarification,$verifyCode, $MaxGradePoint,$CgpaObtained,$CgpaPercentage,$PercentageMarks,$PgMaxGradePoint,$PgCgpaObtained,$PgCgpaPercentage,$PgTotalMarks,$PgMarksObtained,$PgPercentageMarks;

    public static function tableName()
    {
        return 'CandidateQualificationDetailsTbl';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            ['verifyCode', 'captcha','captchaAction' => '/application/qualification/captcha'],
            [['CandidateID', 'CourseID', 'PassStatus', 'YearOfPassing', 'FinalResultAwating', 'QualifyingExamPlaceID', 'QualificationExamStateID','UniversityBoardID',  'ResultMode'], 'integer','message'=>'Field must be an integer'],
            [['verifyCode','clarification'], 'required'],
            [
                'ResultMode', 'required', 'when' => function ($model) {
                    return $model->PassStatus == 1;
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-passstatus :selected').val() == 1; 
                }",
                'message' => "Please select result mode.",
            ],
            //Percentage validation:
            ['TotalMarks', 'required', 'message'=>'Total marks cannot be blank','when' => function ($model) {
                return ($model->PassStatus == 1 && $model->ResultMode == 1); 
               }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-passstatus').val() == 1 && $('#resultmode').val() == 1)}"
            ],
            ['MarksObtained', 'required', 'message'=>'Obtain marks cannot be blank','when' => function ($model) {
                return ($model->PassStatus == 1 && $model->ResultMode == 1); 
               }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-passstatus').val() == 1 && $('#resultmode').val() == 1)}"
            ],
            //CGPA validation:
            //[['MaxGradePoint',], 'number', 'max'=>10],
            ['MaxGradePoint', 'required', 'message'=>'Max grade point cannot be blank','when' => function ($model) {
                return ($model->PassStatus == 1 && $model->ResultMode == 2); 
               }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-passstatus').val() == 1 && $('#resultmode').val() == 2)}"
            ],
            //[['CgpaObtained'], 'number', 'max'=>10],
            //['MarksObtained', 'compare', 'compareAttribute' => 'TotalMarks', 'operator' => '<=','message'=>'Obtained Marks must be less than Total Marks.'],
            
            ['CgpaObtained', 'required', 'message'=>'Obtained CGPA cannot be blank','when' => function ($model) {
                return ($model->PassStatus == 1 && $model->ResultMode == 2); 
               }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-passstatus').val() == 1 && $('#resultmode').val() == 2)}"
            ],
            ['CgpaObtained', 'compare', 'compareValue' => 'MaxGradePoint', 'operator' => '<=','message'=>'Obtained CGPA must be less than Max Grade Point.'],
                       
            ['CgpaPercentage', 'required', 'message'=>'CGPA Percentage can not be blank','when' => function ($model) {
                return ($model->PassStatus == 1 && $model->ResultMode == 2);
                }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-passstatus').val() == 1 && $('#resultmode').val() == 2)}"
            ],
                        
            //['CgpaPercentageMarks', 'required', 'message'=>'Marks can not be blank','when' => function ($model) {
            //    return $model->PassStatus == 1; 
            //   }, 'whenClient' => "function (attribute, value) { return $('#candidatequalificationdetailstbl-passstatus').val() == 1}"
            //],
            
            [
                'OtherCourseName', 'required', 'when' => function ($model) {
                    return ($model->CourseID == '10073');
                    //return ((isset($model->CourseID) && !empty($model->CourseID))?($this->getCourseCodeByCourseId($model->CourseID) == 'OTHER') : $model->CourseID);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-courseid :selected').text() == 'OTHER'; 
                }",
                'message' => "Other Course/Stream cannot be blank.",
            ],
            [
                'OtherUniversityName', 'required', 'when' => function ($model) {
                    return ($model->UniversityBoardID == 0);
                    //return ((isset($model->CourseID) && !empty($model->CourseID))?($this->getCourseCodeByCourseId($model->CourseID) == 'OTHER') : $model->CourseID);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#board-university-name option:selected').text() == 'OTHER';
                }",
                'message' => "University Name cannot be blank."
            ],
            [
                'PostGraduateOtherUniversityName', 'required', 'when' => function ($model) {
                    return ($model->PostGraduateUniversityBoardID == 0);
                    //return ((isset($model->CourseID) && !empty($model->CourseID))?($this->getCourseCodeByCourseId($model->CourseID) == 'OTHER') : $model->CourseID);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#pg-board-university-name option:selected').text() == 'OTHER';
                }",
                'message' => "P.G Other University Name cannot be blank."
            ],

            //  [
            //     'OtherUniversityName', 'required', 'when' => function ($model) {
            //         return ($this->getUniversityId($model->UniversityBoardID) == 'OTHER');
                    
            //     }, 
            //     'whenClient' => "function (attribute, value) { 
            //         return $('#candidatequalificationdetailstbl-otheruniversityname:selected').text() == 'OTHER'; 
            //     }",
            //     'message' => "University Name cannot be blank.",
            // ],


            [['MarksObtained','CgpaPercentageMarks'], 'number','message'=>'Field must be number'],
            [['CreateDate'], 'safe'],
            ['CandidateID','unique'],
            [['clarification'],'required','message'=>'Please select required field'],
            [['QualificationExamStateID'], 'required', 'message'=>'Please select qualifying examination state.'],
            [['CourseID'],'required','message'=>'Please select course/stream.'],
            [['PassStatus'], 'required', 'message'=>'Please select pass status.'],
            //[['FinalResultAwating'], 'required', 'message'=>'Please select Whether in final year/final year result awaited.'],
            ['CandidateID','exist','targetClass' => PersonalDetails::className(), 'targetAttribute' => ['CandidateID' => 'ID']],
            [['YearOfPassing'], 'required', 'message'=>'Please select passing of year/appearing.'],
            [['UniversityBoardID'], 'required', 'message'=>'Please select board/university name.'],
            [['QualifyingExamPlaceID'], 'required', 'message'=>'Please select qualifying examination from.'],
            
            
            [['OtherCourseName','GraduateBscFourYrsEquivCourseName','GraduateInstituteNameAndAddress','GraduateInstitutePincode'], 'trim'],
            [['OtherCourseName','GraduateBscFourYrsEquivCourseName','GraduateInstituteNameAndAddress'], 'string', 'min'=>2, 'max'=>150],
            [['GraduateInstituteNameAndAddress'], 'required', 'message'=>'Please enter Institute Name And Address'],
            [['GraduateInstitutePincode'], 'string', 'min'=>6, 'max'=>6],
            [['GraduateInstitutePincode'], 'required', 'message'=>'Please enter Institute Pincode'],
            ['GraduateInstituteNameAndAddress','match', 'pattern' => "/^[a-zA-Z0-9 ,()-]*$/"],
            ['GraduateInstitutePincode','match', 'pattern' => "/^[a-zA-Z0-9]*$/"],
            [
                'GraduateBscFourYrsEquivCourseName', 'required', 'when' => function ($model) {
                    return ($this->getGraduateCourseCodeByCourseId($model->CourseID) == 6);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-courseid :selected').text() == 'BS 4 YRS EQUIV OR MORE'; 
                }",
                'message' => "Please enter Bsc 4 years-Equivalent Course/Stream",
            ],
            ///////Post Graduate Validation: ////////
            [['PostGraduateInstituteNameAndAddress','PostGraduateInstitutePincode','PostGraduateOtherCourseName','PostGraduateMscEquivCourseName'], 'trim'],
            [['PostGraduateInstituteNameAndAddress','PostGraduateOtherCourseName','PostGraduateMscEquivCourseName'], 'string', 'min'=>2, 'max'=>150],
            [['PostGraduatePassStatus','PostGraduateYearOfPassing','PostGraduateCourseID'], 'integer'],
                        
            
            [['PostGraduatePassStatus'], 'required', 'message'=>'Please select Post Graduate Pass Status.'],
            
            ////////////// When pass status is not applicable Start: ////////////
            //[['PostGraduateYearOfPassing'], 'required', 'message'=>''],
            [
                'PostGraduateYearOfPassing', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == '');
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == ''; 
                }",
                'message' => "Please select p.g. passing of year/appearing.",
            ],
            [
                'PostGraduateYearOfPassing', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 1);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 1; 
                }",
                'message' => "Please select p.g. passing of year/appearing.",
            ],
            [
                'PostGraduateYearOfPassing', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 2);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 2; 
                }",
                'message' => "Please select p.g. passing of year/appearing.",
            ],
            //[['PostGraduateCourseID'],'required','message'=>''],
            [
                'PostGraduateCourseID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == '');
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == ''; 
                }",
                'message' => "Please select p.g. Course/Stream.",
            ],
            [
                'PostGraduateCourseID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 1);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 1; 
                }",
                'message' => "Please select p.g. Course/Stream.",
            ],
            [
                'PostGraduateCourseID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 2);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 2; 
                }",
                'message' => "Please select p.g. Course/Stream.",
            ],
            //[['PostGraduateQualifyingExamPlaceID'],'required','message'=>''],
            [
                'PostGraduateQualifyingExamPlaceID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == '');
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == ''; 
                }",
                'message' => "Please select p.g. Qualifying Examination State.",
            ],
            [
                'PostGraduateQualifyingExamPlaceID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 1);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 1; 
                }",
                'message' => "Please select p.g. Qualifying Examination State.",
            ],
            [
                'PostGraduateQualifyingExamPlaceID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 2);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 2; 
                }",
                'message' => "Please select p.g. Qualifying Examination State.",
            ],
            //[['PostGraduateQualificationExamStateID'],'required','message'=>''],
            [
                'PostGraduateQualificationExamStateID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == '');
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == ''; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            [
                'PostGraduateQualificationExamStateID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 1);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 1; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            [
                'PostGraduateQualificationExamStateID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 2);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 2; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            //[['PostGraduateUniversityBoardID'],'required','message'=>''],
            [
                'PostGraduateUniversityBoardID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == '');
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == ''; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            [
                'PostGraduateUniversityBoardID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 1);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 1; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            [
                'PostGraduateUniversityBoardID', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 2);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 2; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            //[['PostGraduateInstituteNameAndAddress'],'required','message'=>''],
            [
                'PostGraduateInstituteNameAndAddress', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == '');
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == ''; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            [
                'PostGraduateInstituteNameAndAddress', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 1);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 1; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            [
                'PostGraduateInstituteNameAndAddress', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 2);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 2; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            //[['PostGraduateInstitutePincode'],'required','message'=>''],
            [
                'PostGraduateInstitutePincode', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == '');
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == ''; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            [
                'PostGraduateInstitutePincode', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 1);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 1; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            [
                'PostGraduateInstitutePincode', 'required', 'when' => function ($model) {
                    return ($model->PostGraduatePassStatus == 2);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 2; 
                }",
                'message' => "Please select p.g. Qualification Exam State.",
            ],
            ////////////// When pass status is not applicable End: ////////////
            
            
            [
                'PostGraduateOtherCourseName', 'required', 'when' => function ($model) {
                    return ($model->PostGraduateCourseID == '10072');
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatecourseid :selected').text() == 'OTHER'; 
                }",
                'message' => "P.G. Other Course/Stream cannot be blank.",
            ],
            [
                'PostGraduateMscEquivCourseName', 'required', 'when' => function ($model) {
                    return ($model->PostGraduateCourseID == '10068');
                    //return ($this->getPgCourseCodeByCourseId($model->PostGraduateCourseID) == 10);
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatecourseid :selected').val() == '10068'; 
                }",
                'message' => "Please enter P.G. Msc-Equivalent Course/Stream",
            ],    
            [['PostGraduateInstitutePincode'], 'string', 'min'=>6, 'max'=>6],
            ['PostGraduateInstitutePincode','match', 'pattern' => "/^[a-zA-Z0-9]*$/"],
            ['PostGraduateInstituteNameAndAddress','match', 'pattern' => "/^[a-zA-Z0-9 ,()-]*$/"],
                        
            [
                'PostGraduateResultMode', 'required', 'when' => function ($model) {
                    return $model->PostGraduatePassStatus == 1;
                }, 
                'whenClient' => "function (attribute, value) { 
                    return $('#candidatequalificationdetailstbl-postgraduatepassstatus :selected').val() == 1; 
                }",
                'message' => "Please select P.G. Result Mode.",
            ],            
            //P.G Percentage validation:
            ['PgTotalMarks', 'required', 'message'=>'P.G. Total marks cannot be blank','when' => function ($model) {
                return ($model->PostGraduatePassStatus == 1 && $model->PostGraduateResultMode == 1); 
               }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-postgraduatepassstatus').val() == 1 && $('#pgResultmode').val() == 1)}"
            ],
            ['PgMarksObtained', 'required', 'message'=>'P.G. Obtain marks cannot be blank','when' => function ($model) {
                return ($model->PostGraduatePassStatus == 1 && $model->PostGraduateResultMode == 1); 
               }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-postgraduatepassstatus').val() == 1 && $('#pgResultmode').val() == 1)}"
            ],
            //P.G CGPA validation:
            //[['PgMaxGradePoint',], 'number', 'max'=>10],
            ['PgMaxGradePoint', 'required', 'message'=>'Max grade point cannot be blank','when' => function ($model) {
                return ($model->PostGraduatePassStatus == 1 && $model->PostGraduateResultMode == 2); 
               }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-postgraduatepassstatus').val() == 1 && $('#pgResultmode').val() == 2)}"
            ],
            //[['PgCgpaObtained'], 'number', 'max'=>10],
            ['PgCgpaObtained', 'required', 'message'=>'P.G. Obtained CGPA cannot be blank','when' => function ($model) {
                return ($model->PostGraduatePassStatus == 1 && $model->PostGraduateResultMode == 2); 
               }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-postgraduatepassstatus').val() == 1 && $('#pgResultmode').val() == 2)}"
            ],
            ['PgCgpaPercentage', 'required', 'message'=>'CGPA Percentage cannot be blank','when' => function ($model) {
                return ($model->PostGraduatePassStatus == 1 && $model->PostGraduateResultMode == 2); 
               }, 'whenClient' => "function (attribute, value) { return ($('#candidatequalificationdetailstbl-postgraduatepassstatus').val() == 1 && $('#pgResultmode').val() == 2)}"
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'ID' => 'ID',
            'CandidateID' => 'Candidate ID',
            'CourseID' => 'Course ID',
            'OtherCourseName' => 'OtherCourse Name',
            'PassStatus' => 'Pass Status',
            'YearOfPassing' => 'Year Of Passing',
            'FinalResultAwating' => 'Final Result Awating',
            'QualifyingExamPlaceID' => 'Qualifying Exam Place ID',
            'QualificationExamStateID' => 'Qualification Exam State ID',
            'UniversityBoardID' => 'University Board ID',
            'OtherUniversityName' => 'Other University Name ',            
            'ResultMode' => 'Result Mode',
            'MarksObtained' => 'Marks Obtained',
            'TotalMarks'=>' Total mark',
            'clarification'=>'Check point',
            'verifyCode' => 'Verification Code',
            'CgpaPercentageMarks'=>'CGPA/Percentage',
           

        ];
    }
    
    public function getCourseCodeByCourseId($course_id) {
//        $DB = Yii::$app->session->get('NewDB');
//        if (empty($DB)) {
//            return $this->redirect(['/site/login']);
//        }
        $course = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                                        ->bindValue(':select', 'CourseName')
                                        ->bindValue(':input', 'WHERE IsActive=1 AND ID='.$course_id)
                                        ->bindValue(':table', 'CourseMst')
                                        ->queryOne();
        if(isset($course) && !empty($course)){
            return strtoupper($course['CourseName']);
        } else {
            return '';
        }
    }
    
    public function getGraduateCourseCodeByCourseId($course_id) {
        $course = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                                        ->bindValue(':select', 'CourseName,CourseCode')
                                        ->bindValue(':input', "WHERE IsActive=1 AND ID=$course_id ")
                                        ->bindValue(':table', 'CourseMst')
                                        ->queryOne();
        if(isset($course) && !empty($course)){
            //return $course['CourseName'];
            return $course['CourseCode'];
        } else {
            return '';
        }
    }
    
    public function getPgCourseCodeByCourseId($course_id) {
        $course = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
                                        ->bindValue(':select', 'CourseName,CourseCode')
                                        ->bindValue(':input', "WHERE IsActive=1 AND ID=$course_id ")
                                        ->bindValue(':table', 'CourseMst')
                                        ->queryOne();
        if(isset($course) && !empty($course)){
            //return $course['CourseName'];
            return $course['CourseCode'];
        } else {
            return '';
        }
    }
    
    // public function getUniversityId($university_id) {
    //     $university = Yii::$app->db->createCommand("exec getCommonDataSP :select, :input, :table")
    //                                     ->bindValue(':select', 'UniversityBoardName')
    //                                     ->bindValue(':input', 'WHERE IsActive=1 AND ID='.$university_id)
    //                                     ->bindValue(':table', 'UniversityMst')
    //                                     ->queryOne();
    //     if(isset($university) && !empty($university)){
    //         return strtoupper($university['UniversityBoardName']);
    //     } else {
    //         return 'OTHER';
    //     }
    // }
    
    
    
}
