<?php

namespace app\modules\application\models;

use Yii;

/**
 * This is the model class for table "CandidateAddressTbl".
 *
 * @property int $ID
 * @property int|null $CandidateID
 * @property string|null $PremisesName
 * @property string|null $SubLocality
 * @property string|null $Locality
 * @property int|null $CountryID
 * @property int|null $StateUTID
 * @property int|null $DistrictID
 * @property int|null $AddressType
 * @property string|null $PinCode
 * @property string|null $CreateDate
 * @property int|null $IsActive
 *
 * @property CandidateTbl $candidate
 * @property CandidateTbl $candidate0
 * @property CountryMst $country
 * @property CountryMst $country0
 * @property DistrictMst $district
 * @property DistrictMst $district0
 * @property StateMst $stateUT
 * @property StateMst $stateUT0
 */
class ContactDetails extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */

    
    Public $verifyCode,$checkboxName,$CandidateMobile,$AlternateMobile;
    
    public static function tableName()
    {
        return 'CandidateAddressTbl';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['verifyCode'],'required'],
            ['verifyCode', 'captcha','captchaAction' => '/application/contact/captcha'],
            [['PremisesName', 'Locality', 'SubLocality','PinCode','PermanentPremisesName','PermanentLocality','PermanentSubLocality','PermanentPinCode','IsAddressIdentical'], 'filter', 'filter' => 'trim'],
            [['PremisesName','Locality','CountryID','StateUTID','DistrictID','PinCode','PermanentPremisesName','PermanentLocality','PermanentCountryID','PermanentStateUTID','PermanentDistrictID','PermanentPinCode'],'required'],
            ['checkboxName','required',  'message' => 'Please confirm Declaration'],
            [['CandidateID', 'CountryID', 'StateUTID', 'DistrictID', 'PermanentStateUTID','PermanentCountryID','PermanentDistrictID','IsAddressIdentical'], 'integer'],
            [['CreateDate'], 'safe'],
            [['PremisesName','PermanentPremisesName'], 'string', 'max' => 150,'min'=>2],
            [['SubLocality', 'Locality','PermanentLocality','PermanentSubLocality'], 'string', 'max' => 100,'min'=>2],
            //[['PinCode','PermanentPinCode'],'match', 'pattern' => "/^[0-9a-zA-Z]{6}$/", 'message' => 'Please enter valid pincode'],
            [['PinCode','PermanentPinCode'], function ($attribute, $params) {
                if ($this->CountryID==101) {
                    return 'integer';
                } else {
                    return 'string';
                }
            }
            ],
            [['PinCode','PermanentPinCode'], 'string', 'max' => 6,'min'=>6],
            [['CandidateID'], 'exist', 'skipOnError' => true, 'targetClass' => CandidateTbl::class, 'targetAttribute' => ['CandidateID' => 'ID']],
            [['CountryID'], 'exist', 'skipOnError' => true, 'targetClass' => CountryMst::class, 'targetAttribute' => ['CountryID' => 'ID']],
            [['StateUTID'], 'exist', 'skipOnError' => true, 'targetClass' => StateMst::class, 'targetAttribute' => ['StateUTID' => 'ID']],
            [['DistrictID'], 'exist', 'skipOnError' => true, 'targetClass' => DistrictMst::class, 'targetAttribute' => ['DistrictID' => 'ID']],
           
            [['PermanentCountryID'], 'exist', 'skipOnError' => true, 'targetClass' => CountryMst::class, 'targetAttribute' => ['PermanentCountryID' => 'ID']],
            [['PermanentDistrictID'], 'exist', 'skipOnError' => true, 'targetClass' => DistrictMst::class, 'targetAttribute' => ['PermanentDistrictID' => 'ID']],

            ['PinCode', 'match','pattern'=>"/^[0-9]+$/", 'message'=>'Pin code should be numeric and 6 characters long.','when' => function ($model) {
                return $model->CountryID == 101; 
               }, 'whenClient' => "function (attribute, value) { return $('#pr_CountryID').val() == 101}"
            ],
            [['CandidateMobile','AlternateMobile'], 'string', 'max' => 10],
            [['CandidateMobile'], 'required', 'message' => 'Candidate Mobile cannot be blank.'],
           ['PermanentPinCode', 'match','pattern'=>"/^[0-9]+$/", 'message'=>'Pin code should be numeric and 6 characters long.','when' => function ($model) {
            return $model->CountryID == 101; 
           }, 'whenClient' => "function (attribute, value) { return $('#pr_CountryID').val() == 101}"
       ],
          
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'ID' => 'ID',
            'CandidateID' => 'Candidate ID',
            'PremisesName' => 'Premises Name',
            'SubLocality' => 'Sub Locality',
            'Locality' => 'Locality',
            'CountryID' => 'Country Name',
            'StateUTID' => 'State Name',
            'DistrictID' => 'District Name',
            'PinCode' => 'Pin Code',
            'CreateDate' => 'Create Date',
            'IsActive' => 'Is Active',
            'verifyCode' => 'Verification Code',
            'checkboxName' =>'checkboxName',
            'IsAddressIdentical'=>'IsAddressIdentical',
            'PermanentCountryID'=>'Permanent Country Name',
            'PermanentStateUTID'=>'Permanent State Name',
            'PermanentDistrictID'=>'Permanent District Name',
            'PermanentPinCode'=>'Permanent Pin Code',
        ];
    }

    /**
     * Gets query for [[Candidate]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getCandidate()
    {
        return $this->hasOne(CandidateTbl::class, ['ID' => 'CandidateID']);
    }

    /**
     * Gets query for [[Candidate0]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getCandidate0()
    {
        return $this->hasOne(CandidateTbl::class, ['ID' => 'CandidateID']);
    }

    /**
     * Gets query for [[Country]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getCountry()
    {
        return $this->hasOne(CountryMst::class, ['ID' => 'CountryID']);
    }

    /**
     * Gets query for [[Country0]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getCountry0()
    {
        return $this->hasOne(CountryMst::class, ['ID' => 'CountryID']);
    }

    /**
     * Gets query for [[District]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getDistrict()
    {
        return $this->hasOne(DistrictMst::class, ['ID' => 'DistrictID']);
    }

    /**
     * Gets query for [[District0]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getDistrict0()
    {
        return $this->hasOne(DistrictMst::class, ['ID' => 'DistrictID']);
    }

    /**
     * Gets query for [[StateUT]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getStateUT()
    {
        return $this->hasOne(StateMst::class, ['ID' => 'StateUTID']);
    }

    /**
     * Gets query for [[StateUT0]].
     *
     * @return \yii\db\ActiveQuery
     */
    public function getStateUT0()
    {
        return $this->hasOne(StateMst::class, ['ID' => 'StateUTID']);
    }
}
